/* GHtmlDocumentTest.c generated by valac 0.44.3, the Vala compiler
 * generated from GHtmlDocumentTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2011-2013  Richard Schwarting <aquarichy@gmail.com>
 * Copyright (C) 2011-2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Richard Schwarting <aquarichy@gmail.com>
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GHTML_DOCUMENT_TEST (ghtml_document_test_get_type ())
#define GHTML_DOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GHTML_DOCUMENT_TEST, GHtmlDocumentTest))
#define GHTML_DOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GHTML_DOCUMENT_TEST, GHtmlDocumentTestClass))
#define IS_GHTML_DOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GHTML_DOCUMENT_TEST))
#define IS_GHTML_DOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GHTML_DOCUMENT_TEST))
#define GHTML_DOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GHTML_DOCUMENT_TEST, GHtmlDocumentTestClass))

typedef struct _GHtmlDocumentTest GHtmlDocumentTest;
typedef struct _GHtmlDocumentTestClass GHtmlDocumentTestClass;
typedef struct _GHtmlDocumentTestPrivate GHtmlDocumentTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GHtmlDocumentTest {
	GXmlTest parent_instance;
	GHtmlDocumentTestPrivate * priv;
};

struct _GHtmlDocumentTestClass {
	GXmlTestClass parent_class;
};

static gpointer ghtml_document_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType ghtml_document_test_get_type (void) G_GNUC_CONST;
void ghtml_document_test_add_tests (void);
static void __lambda42_ (void);
static void ___lambda42__gtest_func (void);
static void __lambda43_ (void);
static void ___lambda43__gtest_func (void);
static void __lambda44_ (void);
static void ___lambda44__gtest_func (void);
static void __lambda45_ (void);
static void ___lambda45__gtest_func (void);
GHtmlDocumentTest* ghtml_document_test_new (void);
GHtmlDocumentTest* ghtml_document_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);

static void
__lambda42_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGHtmlDocument* doc = NULL;
		GXmlGHtmlDocument* _tmp0_;
		GXmlGHtmlDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlGHtmlDocument* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		GXmlDomElement* n = NULL;
		GXmlGHtmlDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomElement* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
#line 31 "GHtmlDocumentTest.vala"
		_tmp0_ = gxml_ghtml_document_new_from_path (TEST_DIR "/index.html", 0, &_inner_error0_);
#line 31 "GHtmlDocumentTest.vala"
		doc = _tmp0_;
#line 31 "GHtmlDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 156 "GHtmlDocumentTest.c"
			goto __catch57_g_error;
		}
#line 32 "GHtmlDocumentTest.vala"
		g_test_message ("Checking root element...");
#line 33 "GHtmlDocumentTest.vala"
		_tmp1_ = doc;
#line 33 "GHtmlDocumentTest.vala"
		_tmp2_ = gxml_document_get_root ((GXmlDocument*) _tmp1_);
#line 33 "GHtmlDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 33 "GHtmlDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 33 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.root != null");
#line 33 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 34 "GHtmlDocumentTest.vala"
		_tmp5_ = doc;
#line 34 "GHtmlDocumentTest.vala"
		_tmp6_ = gxml_document_get_root ((GXmlDocument*) _tmp5_);
#line 34 "GHtmlDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 34 "GHtmlDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 34 "GHtmlDocumentTest.vala"
		_tmp9_ = gxml_node_get_name (_tmp8_);
#line 34 "GHtmlDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 34 "GHtmlDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 34 "GHtmlDocumentTest.vala"
		_tmp12_ = g_utf8_strdown (_tmp11_, (gssize) -1);
#line 34 "GHtmlDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 34 "GHtmlDocumentTest.vala"
		_tmp14_ = g_utf8_strdown ("html", (gssize) -1);
#line 34 "GHtmlDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 34 "GHtmlDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, _tmp15_) == 0, "doc.root.name.down () == \"html\".down ()");
#line 34 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 34 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 34 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 34 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 35 "GHtmlDocumentTest.vala"
		g_test_message ("Searching for elemento with id 'user'...");
#line 36 "GHtmlDocumentTest.vala"
		_tmp16_ = doc;
#line 36 "GHtmlDocumentTest.vala"
		_tmp17_ = gxml_dom_non_element_parent_node_get_element_by_id ((GXmlDomNonElementParentNode*) _tmp16_, "user", &_inner_error0_);
#line 36 "GHtmlDocumentTest.vala"
		n = _tmp17_;
#line 36 "GHtmlDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 36 "GHtmlDocumentTest.vala"
			_g_object_unref0 (doc);
#line 217 "GHtmlDocumentTest.c"
			goto __catch57_g_error;
		}
#line 37 "GHtmlDocumentTest.vala"
		_tmp18_ = n;
#line 37 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp18_ != NULL, "n != null");
#line 38 "GHtmlDocumentTest.vala"
		_tmp19_ = n;
#line 38 "GHtmlDocumentTest.vala"
		_tmp20_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp19_);
#line 38 "GHtmlDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 38 "GHtmlDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 38 "GHtmlDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "p") == 0, "n.node_name == \"p\"");
#line 38 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp22_);
#line 39 "GHtmlDocumentTest.vala"
		_tmp23_ = n;
#line 39 "GHtmlDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_ELEMENT), "n is GXml.Element");
#line 40 "GHtmlDocumentTest.vala"
		_tmp24_ = n;
#line 40 "GHtmlDocumentTest.vala"
		_tmp25_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GXML_TYPE_ELEMENT, GXmlElement));
#line 40 "GHtmlDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 40 "GHtmlDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 40 "GHtmlDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "") == 0, "((GXml.Element) n).content == \"\"");
#line 40 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 30 "GHtmlDocumentTest.vala"
		_g_object_unref0 (n);
#line 30 "GHtmlDocumentTest.vala"
		_g_object_unref0 (doc);
#line 256 "GHtmlDocumentTest.c"
	}
	goto __finally57;
	__catch57_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
#line 30 "GHtmlDocumentTest.vala"
		e = _inner_error0_;
#line 30 "GHtmlDocumentTest.vala"
		_inner_error0_ = NULL;
#line 42 "GHtmlDocumentTest.vala"
		_tmp28_ = e->message;
#line 42 "GHtmlDocumentTest.vala"
		_tmp29_ = g_strconcat ("ERROR: ", _tmp28_, NULL);
#line 42 "GHtmlDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 42 "GHtmlDocumentTest.vala"
		g_test_message ("%s", _tmp30_);
#line 42 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 43 "GHtmlDocumentTest.vala"
		g_assert_not_reached ();
#line 30 "GHtmlDocumentTest.vala"
		_g_error_free0 (e);
#line 283 "GHtmlDocumentTest.c"
	}
	__finally57:
#line 30 "GHtmlDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 30 "GHtmlDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 30 "GHtmlDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 30 "GHtmlDocumentTest.vala"
		return;
#line 294 "GHtmlDocumentTest.c"
	}
}

static void
___lambda42__gtest_func (void)
{
#line 29 "GHtmlDocumentTest.vala"
	__lambda42_ ();
#line 303 "GHtmlDocumentTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 62 "GHtmlDocumentTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 311 "GHtmlDocumentTest.c"
}

static void
__lambda43_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGHtmlDocument* doc = NULL;
		GXmlGHtmlDocument* _tmp0_;
		GXmlNode* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GXmlElementList* np = NULL;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlElementList* _tmp17_;
		GXmlElementList* _tmp18_;
		GXmlElementList* _tmp19_;
		GXmlElementList* _tmp20_;
		gint _tmp21_;
		gint _tmp22_;
		GXmlDomHTMLCollection* l = NULL;
		GXmlDomHTMLCollection* _tmp23_;
		GXmlDomHTMLCollection* _tmp24_;
		GXmlDomHTMLCollection* _tmp25_;
		gint _tmp26_;
		gint _tmp27_;
		gboolean fdiv = FALSE;
		gboolean fp = FALSE;
#line 48 "GHtmlDocumentTest.vala"
		_tmp0_ = gxml_ghtml_document_new_from_path (TEST_DIR "/index.html", 0, &_inner_error0_);
#line 48 "GHtmlDocumentTest.vala"
		doc = _tmp0_;
#line 48 "GHtmlDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 358 "GHtmlDocumentTest.c"
			goto __catch58_g_error;
		}
#line 49 "GHtmlDocumentTest.vala"
		g_test_message ("Checking root element...");
#line 50 "GHtmlDocumentTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 50 "GHtmlDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 50 "GHtmlDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 50 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.root != null");
#line 50 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 51 "GHtmlDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 51 "GHtmlDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 51 "GHtmlDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 51 "GHtmlDocumentTest.vala"
		_tmp7_ = gxml_node_get_name (_tmp6_);
#line 51 "GHtmlDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 51 "GHtmlDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 51 "GHtmlDocumentTest.vala"
		_tmp10_ = g_utf8_strdown (_tmp9_, (gssize) -1);
#line 51 "GHtmlDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 51 "GHtmlDocumentTest.vala"
		_tmp12_ = g_utf8_strdown ("html", (gssize) -1);
#line 51 "GHtmlDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 51 "GHtmlDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, _tmp13_) == 0, "doc.root.name.down () == \"html\".down ()");
#line 51 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 51 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 51 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 51 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 52 "GHtmlDocumentTest.vala"
		g_test_message ("Searching for element with property class and value app...");
#line 53 "GHtmlDocumentTest.vala"
		_tmp14_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 53 "GHtmlDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 53 "GHtmlDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 53 "GHtmlDocumentTest.vala"
		_tmp17_ = gxml_node_get_elements_by_property_value (_tmp16_, "class", "app");
#line 53 "GHtmlDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 53 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 53 "GHtmlDocumentTest.vala"
		np = _tmp18_;
#line 54 "GHtmlDocumentTest.vala"
		_tmp19_ = np;
#line 54 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp19_ != NULL, "np != null");
#line 55 "GHtmlDocumentTest.vala"
		_tmp20_ = np;
#line 55 "GHtmlDocumentTest.vala"
		_tmp21_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp20_);
#line 55 "GHtmlDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 55 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp22_ == 2, "np.size == 2");
#line 56 "GHtmlDocumentTest.vala"
		g_test_message ("Searching for elemento with class 'app'...");
#line 57 "GHtmlDocumentTest.vala"
		_tmp23_ = gxml_dom_document_get_elements_by_class_name ((GXmlDomDocument*) doc, "app");
#line 57 "GHtmlDocumentTest.vala"
		l = _tmp23_;
#line 58 "GHtmlDocumentTest.vala"
		_tmp24_ = l;
#line 58 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp24_ != NULL, "l != null");
#line 59 "GHtmlDocumentTest.vala"
		_tmp25_ = l;
#line 59 "GHtmlDocumentTest.vala"
		_tmp26_ = gee_collection_get_size ((GeeCollection*) _tmp25_);
#line 59 "GHtmlDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 59 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp27_ == 2, "l.size == 2");
#line 61 "GHtmlDocumentTest.vala"
		fp = FALSE;
#line 61 "GHtmlDocumentTest.vala"
		fdiv = fp;
#line 453 "GHtmlDocumentTest.c"
		{
			GXmlDomHTMLCollection* _e_list = NULL;
			GXmlDomHTMLCollection* _tmp28_;
			GXmlDomHTMLCollection* _tmp29_;
			gint _e_size = 0;
			GXmlDomHTMLCollection* _tmp30_;
			gint _tmp31_;
			gint _tmp32_;
			gint _e_index = 0;
#line 62 "GHtmlDocumentTest.vala"
			_tmp28_ = l;
#line 62 "GHtmlDocumentTest.vala"
			_tmp29_ = _g_object_ref0 (_tmp28_);
#line 62 "GHtmlDocumentTest.vala"
			_e_list = _tmp29_;
#line 62 "GHtmlDocumentTest.vala"
			_tmp30_ = _e_list;
#line 62 "GHtmlDocumentTest.vala"
			_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 62 "GHtmlDocumentTest.vala"
			_tmp32_ = _tmp31_;
#line 62 "GHtmlDocumentTest.vala"
			_e_size = _tmp32_;
#line 62 "GHtmlDocumentTest.vala"
			_e_index = -1;
#line 62 "GHtmlDocumentTest.vala"
			while (TRUE) {
#line 481 "GHtmlDocumentTest.c"
				GXmlDomElement* e = NULL;
				GXmlDomHTMLCollection* _tmp33_;
				gpointer _tmp34_;
				GXmlDomElement* _tmp35_;
				gchar* _tmp36_;
				gchar* _tmp37_;
				gchar* _tmp38_;
				gboolean _tmp39_;
				GXmlDomElement* _tmp40_;
				gchar* _tmp41_;
				gchar* _tmp42_;
				gchar* _tmp43_;
				gboolean _tmp44_;
#line 62 "GHtmlDocumentTest.vala"
				_e_index = _e_index + 1;
#line 62 "GHtmlDocumentTest.vala"
				if (!(_e_index < _e_size)) {
#line 62 "GHtmlDocumentTest.vala"
					break;
#line 501 "GHtmlDocumentTest.c"
				}
#line 62 "GHtmlDocumentTest.vala"
				_tmp33_ = _e_list;
#line 62 "GHtmlDocumentTest.vala"
				_tmp34_ = gee_list_get ((GeeList*) _tmp33_, _e_index);
#line 62 "GHtmlDocumentTest.vala"
				e = (GXmlDomElement*) _tmp34_;
#line 63 "GHtmlDocumentTest.vala"
				_tmp35_ = e;
#line 63 "GHtmlDocumentTest.vala"
				_tmp36_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp35_);
#line 63 "GHtmlDocumentTest.vala"
				_tmp37_ = _tmp36_;
#line 63 "GHtmlDocumentTest.vala"
				_tmp38_ = _tmp37_;
#line 63 "GHtmlDocumentTest.vala"
				_tmp39_ = g_strcmp0 (_tmp38_, "div") == 0;
#line 63 "GHtmlDocumentTest.vala"
				_g_free0 (_tmp38_);
#line 63 "GHtmlDocumentTest.vala"
				if (_tmp39_) {
#line 63 "GHtmlDocumentTest.vala"
					fdiv = TRUE;
#line 525 "GHtmlDocumentTest.c"
				}
#line 64 "GHtmlDocumentTest.vala"
				_tmp40_ = e;
#line 64 "GHtmlDocumentTest.vala"
				_tmp41_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp40_);
#line 64 "GHtmlDocumentTest.vala"
				_tmp42_ = _tmp41_;
#line 64 "GHtmlDocumentTest.vala"
				_tmp43_ = _tmp42_;
#line 64 "GHtmlDocumentTest.vala"
				_tmp44_ = g_strcmp0 (_tmp43_, "p") == 0;
#line 64 "GHtmlDocumentTest.vala"
				_g_free0 (_tmp43_);
#line 64 "GHtmlDocumentTest.vala"
				if (_tmp44_) {
#line 64 "GHtmlDocumentTest.vala"
					fp = TRUE;
#line 543 "GHtmlDocumentTest.c"
				}
#line 62 "GHtmlDocumentTest.vala"
				_g_object_unref0 (e);
#line 547 "GHtmlDocumentTest.c"
			}
#line 62 "GHtmlDocumentTest.vala"
			_g_object_unref0 (_e_list);
#line 551 "GHtmlDocumentTest.c"
		}
#line 66 "GHtmlDocumentTest.vala"
		_vala_assert (fdiv, "fdiv");
#line 67 "GHtmlDocumentTest.vala"
		_vala_assert (fp, "fp");
#line 47 "GHtmlDocumentTest.vala"
		_g_object_unref0 (l);
#line 47 "GHtmlDocumentTest.vala"
		_g_object_unref0 (np);
#line 47 "GHtmlDocumentTest.vala"
		_g_object_unref0 (doc);
#line 563 "GHtmlDocumentTest.c"
	}
	goto __finally58;
	__catch58_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
#line 47 "GHtmlDocumentTest.vala"
		e = _inner_error0_;
#line 47 "GHtmlDocumentTest.vala"
		_inner_error0_ = NULL;
#line 69 "GHtmlDocumentTest.vala"
		_tmp45_ = e->message;
#line 69 "GHtmlDocumentTest.vala"
		_tmp46_ = g_strconcat ("ERROR: ", _tmp45_, NULL);
#line 69 "GHtmlDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 69 "GHtmlDocumentTest.vala"
		g_test_message ("%s", _tmp47_);
#line 69 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp47_);
#line 70 "GHtmlDocumentTest.vala"
		g_assert_not_reached ();
#line 47 "GHtmlDocumentTest.vala"
		_g_error_free0 (e);
#line 590 "GHtmlDocumentTest.c"
	}
	__finally58:
#line 47 "GHtmlDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 47 "GHtmlDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 47 "GHtmlDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 47 "GHtmlDocumentTest.vala"
		return;
#line 601 "GHtmlDocumentTest.c"
	}
}

static void
___lambda43__gtest_func (void)
{
#line 46 "GHtmlDocumentTest.vala"
	__lambda43_ ();
#line 610 "GHtmlDocumentTest.c"
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1477 "glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1477 "glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1477 "glib-2.0.vapi"
	return result;
#line 629 "GHtmlDocumentTest.c"
}

static void
__lambda44_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* sdoc = NULL;
		gchar* _tmp0_;
		GXmlGHtmlDocument* doc = NULL;
		const gchar* _tmp1_;
		GXmlGHtmlDocument* _tmp2_;
		GXmlGHtmlDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlGHtmlDocument* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlNode* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		GXmlElementList* ln = NULL;
		GXmlGHtmlDocument* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlNode* _tmp21_;
		GXmlElementList* _tmp22_;
		GXmlElementList* _tmp23_;
		GXmlElementList* _tmp24_;
		GXmlElementList* _tmp25_;
		gint _tmp26_;
		gint _tmp27_;
		GXmlDomElement* np = NULL;
		GXmlElementList* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlDomHTMLCollection* l = NULL;
		GXmlGHtmlDocument* _tmp35_;
		GXmlDomHTMLCollection* _tmp36_;
		GXmlDomHTMLCollection* _tmp37_;
		GXmlDomHTMLCollection* _tmp38_;
		gint _tmp39_;
		gint _tmp40_;
		GXmlDomElement* sn = NULL;
		GXmlDomHTMLCollection* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNodeList* _tmp49_;
		GXmlDomNodeList* _tmp50_;
		GXmlDomNodeList* _tmp51_;
		gint _tmp52_;
		gint _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomNodeList* _tmp57_;
		GXmlDomNodeList* _tmp58_;
		GXmlDomNodeList* _tmp59_;
		gint _tmp60_;
		gint _tmp61_;
		gchar* _tmp62_ = NULL;
		GXmlGHtmlDocument* _tmp63_;
		gchar* _tmp64_;
		gchar* s = NULL;
		GXmlGHtmlDocument* _tmp65_;
		gchar* _tmp66_;
		const gchar* _tmp67_;
		const gchar* _tmp68_;
#line 75 "GHtmlDocumentTest.vala"
		_tmp0_ = g_strdup ("<!doctype html>\n" \
"<html>\n" \
"<head>\n" \
"  <style>\n" \
"  * { color: red; }\n" \
"  </style>\n" \
"</head>\n" \
"<body>\n" \
"  <script type=\"text/javascript\">\n" \
"  </script>\n" \
"</body>\n" \
"</html>\n");
#line 75 "GHtmlDocumentTest.vala"
		sdoc = _tmp0_;
#line 88 "GHtmlDocumentTest.vala"
		_tmp1_ = sdoc;
#line 88 "GHtmlDocumentTest.vala"
		_tmp2_ = gxml_ghtml_document_new_from_string_doc (_tmp1_, 0);
#line 88 "GHtmlDocumentTest.vala"
		doc = _tmp2_;
#line 89 "GHtmlDocumentTest.vala"
		_tmp3_ = doc;
#line 89 "GHtmlDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) _tmp3_);
#line 89 "GHtmlDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 89 "GHtmlDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 89 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp6_ != NULL, "doc.root != null");
#line 89 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 90 "GHtmlDocumentTest.vala"
		_tmp7_ = doc;
#line 90 "GHtmlDocumentTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) _tmp7_);
#line 90 "GHtmlDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 90 "GHtmlDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 90 "GHtmlDocumentTest.vala"
		_tmp11_ = gxml_node_get_name (_tmp10_);
#line 90 "GHtmlDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 90 "GHtmlDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 90 "GHtmlDocumentTest.vala"
		_tmp14_ = g_utf8_strdown (_tmp13_, (gssize) -1);
#line 90 "GHtmlDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 90 "GHtmlDocumentTest.vala"
		_tmp16_ = g_utf8_strdown ("html", (gssize) -1);
#line 90 "GHtmlDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 90 "GHtmlDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, _tmp17_) == 0, "doc.root.name.down () == \"html\".down ()");
#line 90 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp17_);
#line 90 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 90 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 90 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 91 "GHtmlDocumentTest.vala"
		_tmp18_ = doc;
#line 91 "GHtmlDocumentTest.vala"
		_tmp19_ = gxml_document_get_root ((GXmlDocument*) _tmp18_);
#line 91 "GHtmlDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 91 "GHtmlDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 91 "GHtmlDocumentTest.vala"
		_tmp22_ = gxml_node_get_elements_by_property_value (_tmp21_, "type", "text/javascript");
#line 91 "GHtmlDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 91 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 91 "GHtmlDocumentTest.vala"
		ln = _tmp23_;
#line 92 "GHtmlDocumentTest.vala"
		_tmp24_ = ln;
#line 92 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp24_ != NULL, "ln != null");
#line 93 "GHtmlDocumentTest.vala"
		_tmp25_ = ln;
#line 93 "GHtmlDocumentTest.vala"
		_tmp26_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp25_);
#line 93 "GHtmlDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 93 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp27_ == 1, "ln.size == 1");
#line 94 "GHtmlDocumentTest.vala"
		_tmp28_ = ln;
#line 94 "GHtmlDocumentTest.vala"
		_tmp29_ = gxml_dom_html_collection_item ((GXmlDomHTMLCollection*) _tmp28_, 0);
#line 94 "GHtmlDocumentTest.vala"
		np = _tmp29_;
#line 95 "GHtmlDocumentTest.vala"
		_tmp30_ = np;
#line 95 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp30_ != NULL, "np != null");
#line 96 "GHtmlDocumentTest.vala"
		_tmp31_ = np;
#line 96 "GHtmlDocumentTest.vala"
		_tmp32_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp31_);
#line 96 "GHtmlDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 96 "GHtmlDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 96 "GHtmlDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "script") == 0, "np.node_name == \"script\"");
#line 96 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 97 "GHtmlDocumentTest.vala"
		_tmp35_ = doc;
#line 97 "GHtmlDocumentTest.vala"
		_tmp36_ = gxml_dom_document_get_elements_by_tag_name ((GXmlDomDocument*) _tmp35_, "style");
#line 97 "GHtmlDocumentTest.vala"
		l = _tmp36_;
#line 98 "GHtmlDocumentTest.vala"
		_tmp37_ = l;
#line 98 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp37_ != NULL, "l != null");
#line 99 "GHtmlDocumentTest.vala"
		_tmp38_ = l;
#line 99 "GHtmlDocumentTest.vala"
		_tmp39_ = gee_collection_get_size ((GeeCollection*) _tmp38_);
#line 99 "GHtmlDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 99 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp40_ == 1, "l.size == 1");
#line 100 "GHtmlDocumentTest.vala"
		_tmp41_ = l;
#line 100 "GHtmlDocumentTest.vala"
		_tmp42_ = gxml_dom_html_collection_item (_tmp41_, 0);
#line 100 "GHtmlDocumentTest.vala"
		sn = _tmp42_;
#line 101 "GHtmlDocumentTest.vala"
		_tmp43_ = sn;
#line 101 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp43_ != NULL, "sn != null");
#line 102 "GHtmlDocumentTest.vala"
		_tmp44_ = sn;
#line 102 "GHtmlDocumentTest.vala"
		_tmp45_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp44_);
#line 102 "GHtmlDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 102 "GHtmlDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 102 "GHtmlDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp47_, "style") == 0, "sn.node_name == \"style\"");
#line 102 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp47_);
#line 103 "GHtmlDocumentTest.vala"
		_tmp48_ = sn;
#line 103 "GHtmlDocumentTest.vala"
		_tmp49_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp48_);
#line 103 "GHtmlDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 103 "GHtmlDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 103 "GHtmlDocumentTest.vala"
		_tmp52_ = gxml_dom_node_list_get_length (_tmp51_);
#line 103 "GHtmlDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 103 "GHtmlDocumentTest.vala"
		_tmp54_ = g_strdup_printf ("%i", _tmp53_);
#line 103 "GHtmlDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 103 "GHtmlDocumentTest.vala"
		g_message ("GHtmlDocumentTest.vala:103: %s", _tmp55_);
#line 103 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp55_);
#line 103 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp51_);
#line 104 "GHtmlDocumentTest.vala"
		_tmp56_ = sn;
#line 104 "GHtmlDocumentTest.vala"
		_tmp57_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp56_);
#line 104 "GHtmlDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 104 "GHtmlDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 104 "GHtmlDocumentTest.vala"
		_tmp60_ = gxml_dom_node_list_get_length (_tmp59_);
#line 104 "GHtmlDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 104 "GHtmlDocumentTest.vala"
		_vala_assert (_tmp61_ == 1, "sn.child_nodes.length == 1");
#line 104 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 105 "GHtmlDocumentTest.vala"
		_tmp63_ = doc;
#line 105 "GHtmlDocumentTest.vala"
		_tmp64_ = gxml_dom_html_document_to_html ((GXmlDomHtmlDocument*) _tmp63_, &_inner_error0_);
#line 105 "GHtmlDocumentTest.vala"
		_tmp62_ = _tmp64_;
#line 105 "GHtmlDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 105 "GHtmlDocumentTest.vala"
			_g_object_unref0 (sn);
#line 105 "GHtmlDocumentTest.vala"
			_g_object_unref0 (l);
#line 105 "GHtmlDocumentTest.vala"
			_g_object_unref0 (np);
#line 105 "GHtmlDocumentTest.vala"
			_g_object_unref0 (ln);
#line 105 "GHtmlDocumentTest.vala"
			_g_object_unref0 (doc);
#line 105 "GHtmlDocumentTest.vala"
			_g_free0 (sdoc);
#line 915 "GHtmlDocumentTest.c"
			goto __catch59_g_error;
		}
#line 105 "GHtmlDocumentTest.vala"
		g_message ("GHtmlDocumentTest.vala:105: %s", _tmp62_);
#line 106 "GHtmlDocumentTest.vala"
		_tmp65_ = doc;
#line 106 "GHtmlDocumentTest.vala"
		_tmp66_ = gxml_dom_html_document_to_html ((GXmlDomHtmlDocument*) _tmp65_, &_inner_error0_);
#line 106 "GHtmlDocumentTest.vala"
		s = _tmp66_;
#line 106 "GHtmlDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 106 "GHtmlDocumentTest.vala"
			_g_free0 (_tmp62_);
#line 106 "GHtmlDocumentTest.vala"
			_g_object_unref0 (sn);
#line 106 "GHtmlDocumentTest.vala"
			_g_object_unref0 (l);
#line 106 "GHtmlDocumentTest.vala"
			_g_object_unref0 (np);
#line 106 "GHtmlDocumentTest.vala"
			_g_object_unref0 (ln);
#line 106 "GHtmlDocumentTest.vala"
			_g_object_unref0 (doc);
#line 106 "GHtmlDocumentTest.vala"
			_g_free0 (sdoc);
#line 942 "GHtmlDocumentTest.c"
			goto __catch59_g_error;
		}
#line 107 "GHtmlDocumentTest.vala"
		_tmp67_ = s;
#line 107 "GHtmlDocumentTest.vala"
		g_message ("GHtmlDocumentTest.vala:107: %s", _tmp67_);
#line 108 "GHtmlDocumentTest.vala"
		_tmp68_ = s;
#line 108 "GHtmlDocumentTest.vala"
		_vala_assert (string_contains (_tmp68_, "style>\n  * { color: red; }\n  </style>"), "\"style>\\n  * { color: red; }\\n  </style>\" in s");
#line 74 "GHtmlDocumentTest.vala"
		_g_free0 (s);
#line 74 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp62_);
#line 74 "GHtmlDocumentTest.vala"
		_g_object_unref0 (sn);
#line 74 "GHtmlDocumentTest.vala"
		_g_object_unref0 (l);
#line 74 "GHtmlDocumentTest.vala"
		_g_object_unref0 (np);
#line 74 "GHtmlDocumentTest.vala"
		_g_object_unref0 (ln);
#line 74 "GHtmlDocumentTest.vala"
		_g_object_unref0 (doc);
#line 74 "GHtmlDocumentTest.vala"
		_g_free0 (sdoc);
#line 969 "GHtmlDocumentTest.c"
	}
	goto __finally59;
	__catch59_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
#line 74 "GHtmlDocumentTest.vala"
		e = _inner_error0_;
#line 74 "GHtmlDocumentTest.vala"
		_inner_error0_ = NULL;
#line 110 "GHtmlDocumentTest.vala"
		_tmp69_ = e->message;
#line 110 "GHtmlDocumentTest.vala"
		_tmp70_ = g_strconcat ("ERROR: ", _tmp69_, NULL);
#line 110 "GHtmlDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 110 "GHtmlDocumentTest.vala"
		g_test_message ("%s", _tmp71_);
#line 110 "GHtmlDocumentTest.vala"
		_g_free0 (_tmp71_);
#line 111 "GHtmlDocumentTest.vala"
		g_assert_not_reached ();
#line 74 "GHtmlDocumentTest.vala"
		_g_error_free0 (e);
#line 996 "GHtmlDocumentTest.c"
	}
	__finally59:
#line 74 "GHtmlDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 74 "GHtmlDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 74 "GHtmlDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 74 "GHtmlDocumentTest.vala"
		return;
#line 1007 "GHtmlDocumentTest.c"
	}
}

static void
___lambda44__gtest_func (void)
{
#line 73 "GHtmlDocumentTest.vala"
	__lambda44_ ();
#line 1016 "GHtmlDocumentTest.c"
}

static void
__lambda45_ (void)
{
	gchar* src = NULL;
	gchar* _tmp0_;
	GXmlDomDocument* doc = NULL;
	const gchar* _tmp1_;
	GXmlGHtmlDocument* _tmp2_;
	GXmlDomDocument* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GXmlDomDocument* _tmp6_;
	GXmlDomElement* _tmp7_;
	GXmlDomElement* _tmp8_;
	GXmlDomElement* _tmp9_;
	GXmlDomElementList* c = NULL;
	GXmlDomDocument* _tmp10_;
	GXmlDomElement* _tmp11_;
	GXmlDomElement* _tmp12_;
	GXmlDomElement* _tmp13_;
	GXmlDomElementList* _tmp14_;
	GXmlDomElementList* _tmp15_;
	GXmlDomElementList* collection = NULL;
	GXmlDomDocument* _tmp27_;
	GXmlDomElementList* _tmp28_;
	GXmlDomElementList* _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	GXmlDomElementList* _tmp34_;
	gint _tmp35_;
	gint _tmp36_;
#line 126 "GHtmlDocumentTest.vala"
	_tmp0_ = g_strdup ("\n" \
"<!--[if lt IE 7]>      <html dir=\"ltr\" lang=\"fr\" data-locale=\"fr\"" \
" data-locale-long=\"fr_FR\" data-locale-name=\"French (France)\" data-" \
"locale-facebook=\"fr_FR\" data-locale-twitter=\"fr\" data-locale-googl" \
"e=\"fr\" data-locale-linkedin=\"fr_FR\" class=\"no-js lt-ie9 lt-ie8 lt" \
"-ie7 \"> <![endif]-->\n" \
"<!--[if IE 7]>         <html dir=\"ltr\" lang=\"fr\" data-locale=\"fr\"" \
" data-locale-long=\"fr_FR\" data-locale-name=\"French (France)\" data-" \
"locale-facebook=\"fr_FR\" data-locale-twitter=\"fr\" data-locale-googl" \
"e=\"fr\" data-locale-linkedin=\"fr_FR\" class=\"no-js lt-ie9 lt-ie8\">" \
" <![endif]-->\n" \
"<!--[if IE 8]>         <html dir=\"ltr\" lang=\"fr\" data-locale=\"fr\"" \
" data-locale-long=\"fr_FR\" data-locale-name=\"French (France)\" data-" \
"locale-facebook=\"fr_FR\" data-locale-twitter=\"fr\" data-locale-googl" \
"e=\"fr\" data-locale-linkedin=\"fr_FR\" class=\"no-js lt-ie9\"> <![end" \
"if]-->\n" \
"<!--[if gt IE 8]><!-->\n" \
"<html dir=\"ltr\" lang=\"fr\" data-locale=\"fr\" data-locale-long=\"fr" \
"_FR\" data-locale-name=\"French (France)\" data-locale-facebook=\"fr_F" \
"R\" data-locale-twitter=\"fr\" data-locale-google=\"fr\" data-locale-l" \
"inkedin=\"fr_FR\" class=\"no-js \"><!--<![endif]--><head prefix=\"og: " \
"http://ogp.me/ns# fb: http://ogp.me/ns/fb# article: http://ogp.me/ns/a" \
"rticle#\"><meta charset=\"UTF-8\"/><title>Climat&#xA0;: la Chine est-e" \
"lle le nouveau leader ? - France 24</title><meta http-equiv=\"X-UA-Com" \
"patible\" content=\"IE=edge\"/><meta name=\"viewport\" content=\"width" \
"=device-width, initial-scale=1, maximum-scale=1\"/><meta name=\"title\"" \
" content=\"Climat&#xA0;: la Chine est-elle le nouveau leader ? - Franc" \
"e 24\"/><meta name=\"description\" content=\"&#xC9;L&#xC9;MENT TERRE :" \
" Autrefois mauvaise &#xE9;l&#xE8;ve des n&#xE9;gociations climatiques," \
" la Chine a chang&#xE9; de cap. D&#xE9;sormais, P&#xE9;kin investit ma" \
"ssivement dans les &#xE9;nergies...\"/><link rel=\"search\" type=\"app" \
"lication/opensearchdescription+xml\" href=\"/opensearch_fr.xml?version" \
"=20171213121500\" title=\"France 24\"/><meta name=\"apple-mobile-web-a" \
"pp-capable\" content=\"yes\"/><meta name=\"apple-mobile-web-app-status" \
"-bar-style\" content=\"black-translucent\"/><meta name=\"apple-mobile-" \
"web-app-title\" content=\"France 24\"/><meta name=\"application-name\"" \
" content=\"France 24\"/><link rel=\"shortcut icon\" href=\"/favicon.ic" \
"o?version=20171213121500\" type=\"image/x-icon\"/><link rel=\"apple-to" \
"uch-icon\" href=\"/apple-touch-icon-57x57.png?version=20171213121500\"" \
" sizes=\"57x57\"/><link rel=\"apple-touch-icon\" href=\"/apple-touch-i" \
"con-60x60.png?version=20171213121500\" sizes=\"60x60\"/><link rel=\"ap" \
"ple-touch-icon\" href=\"/apple-touch-icon-72x72.png?version=2017121312" \
"1500\" sizes=\"72x72\"/><link rel=\"apple-touch-icon\" href=\"/apple-t" \
"ouch-icon-76x76.png?version=20171213121500\" sizes=\"76x76\"/><link re" \
"l=\"apple-touch-icon\" href=\"/apple-touch-icon-114x114.png?version=20" \
"171213121500\" sizes=\"114x114\"/><link rel=\"apple-touch-icon\" href=" \
"\"/apple-touch-icon-120x120.png?version=20171213121500\" sizes=\"120x1" \
"20\"/><link rel=\"apple-touch-icon\" href=\"/apple-touch-icon-144x144." \
"png?version=20171213121500\" sizes=\"144x144\"/><link rel=\"apple-touc" \
"h-icon\" href=\"/apple-touch-icon-152x152.png?version=20171213121500\"" \
" sizes=\"152x152\"/><link rel=\"apple-touch-icon\" href=\"/apple-touch" \
"-icon-180x180.png?version=20171213121500\" sizes=\"180x180\"/><link re" \
"l=\"icon\" type=\"image/png\" href=\"/favicon-16x16.png?version=201712" \
"13121500\" sizes=\"16x16\"/><link rel=\"icon\" type=\"image/png\" href" \
"=\"/favicon-32x32.png?version=20171213121500\" sizes=\"32x32\"/><link " \
"rel=\"icon\" type=\"image/png\" href=\"/favicon-48x48.png?version=2017" \
"1213121500\" sizes=\"48x48\"/><link rel=\"icon\" type=\"image/png\" hr" \
"ef=\"/favicon-64x64.png?version=20171213121500\" sizes=\"64x64\"/><lin" \
"k rel=\"icon\" type=\"image/png\" href=\"/favicon-96x96.png?version=20" \
"171213121500\" sizes=\"96x96\"/><link rel=\"icon\" type=\"image/png\" " \
"href=\"/favicon-160x160.png?version=20171213121500\" sizes=\"160x160\"" \
"/><link rel=\"icon\" type=\"image/png\" href=\"/favicon-192x192.png?ve" \
"rsion=20171213121500\" sizes=\"192x192\"/><meta name=\"msapplication-T" \
"ileColor\" content=\"#454349\"/><meta name=\"msapplication-TileImage\"" \
" content=\"/mstile-144x144.png?version=20171213121500\"/><link rel=\"i" \
"con\" type=\"image/x-icon\" href=\"/favicon.ico?version=20171213121500" \
"\"/><meta property=\"og:site_name\" content=\"France 24\"/><meta prope" \
"rty=\"og:url\" content=\"http://www.france24.com/fr/20171021-chine-cha" \
"rbon-centrale-etranger-energie-environnement-leader-climat\"/><meta pr" \
"operty=\"og:type\" content=\"article\"/><meta property=\"og:image\" co" \
"ntent=\"http://scd.france24.com/fr/files_fr/imagecache/home_1024/editi" \
"on/fr_element_terre_chine_charbon_pad.sub_.01.jpg\"/><meta property=\"" \
"og:image:width\" content=\"1024\"/><meta property=\"og:image:height\" " \
"content=\"576\"/><meta property=\"og:image:type\" content=\"image/jpg\"" \
"/><meta property=\"og:title\" content=\"Climat&#xA0;: la Chine est-ell" \
"e le nouveau leader ? - France 24\"/><meta property=\"og:description\"" \
" content=\"&#xC9;L&#xC9;MENT TERRE : Autrefois mauvaise &#xE9;l&#xE8;v" \
"e des n&#xE9;gociations climatiques, la Chine a chang&#xE9; de cap. D&" \
"#xE9;sormais, P&#xE9;kin investit massivement dans les &#xE9;nergies.." \
".\"/><meta property=\"fb:app_id\" content=\"121241974571942\"/><meta p" \
"roperty=\"fb:pages\" content=\"153632746935\"/><meta name=\"twitter:ca" \
"rd\" content=\"summary_large_image\"/><meta name=\"twitter:url\" conte" \
"nt=\"http://www.france24.com/fr/20171021-chine-charbon-centrale-etrang" \
"er-energie-environnement-leader-climat\"/><meta name=\"twitter:creator" \
"\" content=\"@France24_fr\"/><meta name=\"twitter:site\" content=\"@FR" \
"ANCE24\"/><meta name=\"twitter:image\" content=\"http://scd.france24.c" \
"om/fr/files_fr/imagecache/home_1024/edition/fr_element_terre_chine_cha" \
"rbon_pad.sub_.01.jpg\"/><meta name=\"twitter:title\" content=\"Climat&" \
"#xA0;: la Chine est-elle le nouveau leader ? - France 24\"/><meta name" \
"=\"twitter:description\" content=\"&#xC9;L&#xC9;MENT TERRE : Autrefois" \
" mauvaise &#xE9;l&#xE8;ve des n&#xE9;gociations climatiques, la Chine " \
"a chang&#xE9; de cap. D&#xE9;sormais, P&#xE9;kin investit massivement " \
"dans les &#xE9;nergies...\"/><meta name=\"twitter:domain\" content=\"F" \
"RANCE24.com\"/><meta name=\"twitter:account_id\" content=\"1994321\"/>" \
"<meta name=\"twitter:app:id:iphone\" content=\"364379394\"/><meta name" \
"=\"twitter:app:id:ipad\" content=\"364379394\"/><meta name=\"twitter:a" \
"pp:id:googleplay\" content=\"com.france24.androidapp\"/><meta name=\"a" \
"pple-itunes-app\" content=\"app-id=364379394\"/><meta name=\"msApplica" \
"tion-ID\" content=\"57d03d56-dd7c-449e-8fa1-a87c090f54df\"/><meta name" \
"=\"msApplication-PackageFamilyName\" content=\"FRANCE24.FRANCE24-MCD-R" \
"FI_3zfmvk45gp28r\"/><meta name=\"twitter:app:name:iphone\" content=\"F" \
"RANCE 24\"/><meta name=\"twitter:app:name:ipad\" content=\"FRANCE 24\"" \
"/><meta name=\"twitter:app:name:googleplay\" content=\"FRANCE 24 pour " \
"Android\"/><meta property=\"og:locale\" content=\"fr_FR\"/><link href=" \
"\"https://plus.google.com/116536894056162235467/\" rel=\"publisher\"/>" \
"<meta property=\"article:publisher\" content=\"http://www.facebook.com" \
"/FRANCE24\"/><meta property=\"article:author\" content=\"http://www.fa" \
"cebook.com/FRANCE24\"/><meta property=\"article:published_time\" conte" \
"nt=\"2017-10-18T18:01:28+02:00\"/><meta property=\"article:modified_ti" \
"me\" content=\"2017-10-20T15:14:13+02:00\"/><meta property=\"article:s" \
"ection\" content=\"&#xC9;L&#xC9;MENT TERRE\"/><meta property=\"article" \
":tag\" content=\"Chine\"/><meta property=\"article:tag\" content=\"Cli" \
"mat\"/><meta property=\"article:tag\" content=\"&#xC9;nergies renouvel" \
"ables\"/><link rel=\"alternate\" href=\"android-app://com.france24.and" \
"roidapp/f24/fr/show/WB5190871-F24-FR-20171018\"/><meta name=\"twitter:" \
"app:url:googleplay\" content=\"f24://fr/show/WB5190871-F24-FR-20171018" \
"\"/><link rel=\"canonical\" href=\"http://www.france24.com/fr/20171021" \
"-chine-charbon-centrale-etranger-energie-environnement-leader-climat\"" \
"/><link rel=\"alternate\" media=\"only screen and (max-width: 640px)\"" \
" href=\"http://m.france24.com/fr/20171021-chine-charbon-centrale-etran" \
"ger-energie-environnement-leader-climat\"/><link rel=\"stylesheet\" ty" \
"pe=\"text/css\" href=\"/css/compiled/main.css?version=20171213121500\"" \
"/><link rel=\"stylesheet\" type=\"text/css\" href=\"/css/compiled/prin" \
"t.css?version=20171213121500\" media=\"print\"/><script type=\"text/ja" \
"vascript\" src=\"/bundles/aefhermesf24/js/hacks.js?version=20171213121" \
"500\"/><!-- [if lt IE 9] --><script type=\"text/javascript\" src=\"/bu" \
"ndles/aefhermesf24/js/vendor/modernizr.js?version=20171213121500\"/><s" \
"cript type=\"text/javascript\" src=\"/bundles/aefhermesf24/js/vendor/r" \
"espond.min.js?version=20171213121500\"/><!-- [endif] --><script type=\"" \
"text/javascript\"><![CDATA[\n" \
"                var domainConfig = {\n" \
"    baseDomain: \"france24.com\",\n" \
"    defaultSubdomain: \"www\",\n" \
"    mobileSubdomain: \"m\",\n" \
"    tabletSubdomain: \"t\",\n" \
"    currentSubdomain: \"www\",\n" \
"    currentLocale: {\n" \
"        short: \"fr\",\n" \
"        long: \"fr_FR\"\n" \
"    }\n" \
"};\n" \
"var isAefHermes = true;\n" \
"\n" \
"    window.janrainEnabled = true;\n" \
"\n" \
"            ]]></script><script type=\"text/javascript\"><![CDATA[\n" \
"                var specialEventId = '';\n" \
"            ]]></script><script type=\"text/javascript\" src=\"/js/com" \
"piled/mobile-redirect.js?version=20171213121500\"/><script type=\"text" \
"/javascript\" data-main=\"/js/main.built.js?version=20171213121500\" s" \
"rc=\"/js/require.js?version=20171213121500\" async=\"\"/><script class" \
"=\"tc-config-vars\" type=\"text/javascript\"><![CDATA[<!--\n" \
"var tms_vars = {};\n" \
"tms_vars[\"page\"] = \"Detail\\x20page\";\n" \
"tms_vars[\"env_context\"] = \"main\";\n" \
"tms_vars[\"reqtag\"] = \"\";\n" \
"tms_vars[\"locale\"] = \"fr\";\n" \
"tms_vars[\"sous-repertoire\"] = \"\\u00C9L\\u00C9MENT\\x20TERRE\";\n" \
"tms_vars[\"aef_libelle_contenu_page\"] = \"\\u00C9L\\u00C9MENT\\x20TER" \
"RE\\x2DClimat\\u00A0\\x3A\\x20la\\x20Chine\\x20est\\x2Delle\\x20le\\x2" \
"0nouveau\\x20leader\\x20\\x3F\";\n" \
"tms_vars[\"aef_id_contenu\"] = \"WB5190871\\x2DF24\\x2DFR\\x2D20171018" \
"\";\n" \
"tms_vars[\"aef_marque\"] = \"france24\";\n" \
"tms_vars[\"aef_rep1\"] = \"emission\";\n" \
"tms_vars[\"aef_rep2\"] = \"element\\x2Dterre\";\n" \
"tms_vars[\"aef_rep3\"] = \"defaut\";\n" \
"tms_vars[\"aef_rep_global\"] = \"emission\";\n" \
"tms_vars[\"aef_thema\"] = \"chine,climat,energies\\x20renouvelables\";" \
"\n" \
"tms_vars[\"aef_type_page1\"] = \"edition\";\n" \
"tms_vars[\"aef_auteur\"] = \"marina\\x20bertsch,\\x20mairead\\x20dunda" \
"s,\\x20juliette\\x20lacharnay,\\x20valerie\\x20dekimpe\";\n" \
"tms_vars[\"aef_acces\"] = \"gratuit\";\n" \
"tms_vars[\"markup_ftp\"] = \"emissions\";\n" \
"tms_vars[\"nom_page\"] = \"climat\\x3A\\x2Dla\\x2Dchine\\x2Dest\\x2Del" \
"le\\x2Dle\\x2Dnouveau\\x2Dleader\\x2D\\x3F\";\n" \
"tms_vars[\"aef_dpubli\"] = \"2017\\x2D10\\x2D20\";\n" \
"tms_vars[\"aef_hpubli\"] = \"15\\x3A14\";\n" \
"tms_vars[\"aef_type_contenu1\"] = \"video\";\n" \
"tms_vars[\"env_work\"] = 'prod';\n" \
"tms_vars[\"aef_version_environnement\"] = 'v3.0.22';\n" \
"        var tc_vars = {};\n" \
"window.tc_vars = tms_vars;\n" \
"//-->]]></script><script type=\"application/ld+json\"><![CDATA[{\"@con" \
"text\":\"http:\\/\\/schema.org\",\"@type\":\"NewsArticle\",\"mainEntit" \
"yOfPage\":\"True\",\"url\":\"http:\\/\\/www.france24.com\\/fr\\/201710" \
"21-chine-charbon-centrale-etranger-energie-environnement-leader-climat" \
"\",\"thumbnailUrl\":\"http:\\/\\/scd.france24.com\\/fr\\/files_fr\\/im" \
"agecache\\/home_1024\\/edition\\/fr_element_terre_chine_charbon_pad.su" \
"b_.01.jpg\",\"headline\":\"Climat\\u00a0: la Chine est-elle le nouveau" \
" leader ?\",\"alternativeHeadline\":\"\\u003Cp\\u003EAutrefois mauvais" \
"e \\u00e9l\\u00e8ve des n\\u00e9gociations climatiques, la Chine a cha" \
"ng\\u00e9 de cap. D\\u00e9sormais, P\\u00e9kin investit massivement da" \
"ns les \\u00e9nergies renouvelables et participe \\u00e0 l\\u2019effor" \
"t collectif, occupant la chaise vide laiss\\u00e9e par les \\u00c9tats" \
"-Unis de Donald Trump. Mais par ailleurs, des entreprises publiques ch" \
"inoises sont li\\u00e9es \\u00e0 une centaine de projets de centrales " \
"\\u00e0 charbon \\u00e0 l'\\u00e9tranger. La Chine peut-elle tout de m" \
"\\u00eame \\u00eatre consid\\u00e9r\\u00e9e comme un h\\u00e9ros du cl" \
"imat ? Ou joue-t-elle un double jeu\\u00a0?\\u003C\\/p\\u003E\",\"desc" \
"ription\":\"\\u003Cp\\u003EAutrefois mauvaise \\u00e9l\\u00e8ve des n\\" \
"u00e9gociations climatiques, la Chine a chang\\u00e9 de cap. D\\u00e9s" \
"ormais, P\\u00e9kin investit massivement dans les \\u00e9nergies renou" \
"velables et participe \\u00e0 l\\u2019effort collectif, occupant la ch" \
"aise vide laiss\\u00e9e par les \\u00c9tats-Unis de Donald Trump. Mais" \
" par ailleurs, des entreprises publiques chinoises sont li\\u00e9es \\" \
"u00e0 une centaine de projets de centrales \\u00e0 charbon \\u00e0 l'\\" \
"u00e9tranger. La Chine peut-elle tout de m\\u00eame \\u00eatre consid\\" \
"u00e9r\\u00e9e comme un h\\u00e9ros du climat ? Ou joue-t-elle un doub" \
"le jeu\\u00a0?\\u003C\\/p\\u003E\",\"image\":{\"@type\":\"ImageObject\"" \
",\"url\":\"http:\\/\\/scd.france24.com\\/fr\\/files_fr\\/imagecache\\/" \
"home_1024\\/edition\\/fr_element_terre_chine_charbon_pad.sub_.01.jpg\"" \
",\"width\":\"1024\",\"height\":\"576\"},\"keywords\":[\"Chine\",\"Clim" \
"at\",\"\\u00c9nergies renouvelables\"],\"datePublished\":\"2017-10-18T" \
"18:01:28Z\",\"dateCreated\":\"2017-10-18T18:01:28Z\",\"dateModified\":" \
"\"2017-10-20T15:14:13Z\",\"articleSection\":\"emission-\\u00c9L\\u00c9" \
"MENT TERRE\",\"creator\":\"Marina BERTSCH\",\"author\":[{\"@type\":\"P" \
"erson\",\"name\":\"Marina BERTSCH\",\"url\":\"http:\\/\\/www.france24." \
"com\"},{\"@type\":\"Person\",\"name\":\"Mairead DUNDAS\",\"url\":\"htt" \
"p:\\/\\/www.france24.com\"},{\"@type\":\"Person\",\"name\":\"Juliette " \
"LACHARNAY\",\"url\":\"http:\\/\\/www.france24.com\"},{\"@type\":\"Pers" \
"on\",\"name\":\"Val\\u00e9rie DEKIMPE\",\"url\":\"http:\\/\\/www.franc" \
"e24.com\"}],\"publisher\":{\"@type\":\"Organization\",\"name\":\"Franc" \
"e 24\",\"url\":\"https:\\/\\/plus.google.com\\/116536894056162235467\\" \
"/\",\"logo\":{\"@type\":\"ImageObject\",\"url\":\"http:\\/\\/static.fr" \
"ance24.com\\/meta_og_twcards\\/jsonld_publisher.png\",\"width\":\"1200" \
"\",\"height\":\"1200\"}}}]]></script></head><body class=\"desktop flui" \
"d-transition\">\n" \
"            <div class=\"side-bar\">\n" \
"                            <header class=\"identity\"><div class=\"lo" \
"go\">\n" \
"                            <a href=\"/fr/\">\n" \
"                                France 24 : L&#x2019;actualit&#xE9; in" \
"ternationale 24h / 24                            </a>\n" \
"                        </div>\n" \
"                                        <p>L&#x2019;actualit&#xE9; int" \
"ernationale 24H / 24</p>\n" \
"                </header><nav class=\"main-nav\"><ul><li class=\"nav-f" \
"ilters\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/\" class=\"modeless\" title=\"Infos, news &amp" \
"; actualit&#xE9;s - L'information internationale en direct\">\n" \
"                            A la une\n" \
"                        </a>\n" \
"                                                                      " \
"      <dl class=\"mn-filters\"><dt>Filtrer la page :</dt>\n" \
"                                <dd><a class=\"modeless filter\" title" \
"=\"Infos, news &amp; actualit&#xE9;s - L'information internationale en" \
" direct\" href=\"http://www.france24.com/fr/depeches/\">AFP</a></dd>\n" \
"                                <dd><a class=\"modeless filter\" title" \
"=\"Les derni&#xE8;res 24h\" href=\"http://www.france24.com/fr/home/24h" \
"/1/\">24h</a></dd>\n" \
"                                <dd><a class=\"modeless filter\" title" \
"=\"Vid&#xE9;os\" href=\"http://www.france24.com/fr/video/\">Vid&#xE9;o" \
"s</a></dd>\n" \
"                            </dl></li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/video/\" class=\"modeless\" title=\"Vid&#xE9;o" \
"s News - Actualit&#xE9; vid&#xE9;o - France24\">\n" \
"                            Vid&#xE9;os\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/france/\" class=\"modeless\" title=\"FRANCE : " \
"News et actualit&#xE9; en continu - France 24\">\n" \
"                            France\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/afrique/\" class=\"modeless\" title=\"Politiqu" \
"e &amp; &#xE9;conomie en AFRIQUE, infos &amp; news au Maghreb - France" \
" 24\">\n" \
"                            Afrique\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/moyen-orient/\" class=\"modeless\" title=\"Inf" \
"ormations et news au MOYEN-ORIENT - Toute l'actualit&#xE9; sur France " \
"24\">\n" \
"                            Moyen-orient\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/europe/\" class=\"modeless\" title=\"News, act" \
"ualit&#xE9; politique &amp; &#xE9;conomique en Europe - France 24\">\n" \
"                            Europe\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/ameriques/\" class=\"modeless\" title=\"Am&#xE" \
"9;riques : information en direct, news et actu en continu - France 24\"" \
">\n" \
"                            Am&#xE9;riques\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/asie-pacifique/\" class=\"modeless\" title=\"A" \
"sie et Pacifique : actualit&#xE9; internationale en continu - France 2" \
"4\">\n" \
"                            Asie-pacifique\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/sports/\" class=\"modeless\" title=\"SPORT : t" \
"outes les news sportives et les r&#xE9;sultats - France 24\">\n" \
"                            Sports\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/eco-tech/\" class=\"modeless\" title=\"&#xC9;C" \
"ONOMIE &amp; TECHNOLOGIE : toute l'actu &#xE9;co &amp; tech  - France " \
"24\">\n" \
"                            &#xC9;co/tech\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/culture/\" class=\"modeless\" title=\"CULTURE " \
"&amp; artistes : l'actualit&#xE9; culturelle &amp; artistique - France" \
" 24\">\n" \
"                            Culture\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                          \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/planete/\" class=\"modeless\" title=\"PLAN&#xC" \
"8;TE : toute l'actu environnement - France 24\">\n" \
"                            Plan&#xE8;te\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                                      " \
"                        \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/reportages/\" class=\"modeless light\" title=\"" \
"Tous les reportages des grands reporters de France 24 aux 4 coins du m" \
"onde\">\n" \
"                            Reportages\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                                      " \
"                        \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/emissions/\" class=\"modeless light\" title=\"" \
"Programmes TV, Emissions et news en VOD\">\n" \
"                            &#xC9;missions\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                                      " \
"                        \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"          <a href=\"/fr/webdocumentaires/\" class=\"modeless light\" t" \
"itle=\"Webdocumentaires et Infographies - France 24\">\n" \
"                            Infographies\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                                      " \
"                        \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"<a href=\"http://www.infomigrants.net/fr/\" class=\"item-im\" title=\"" \
"InfoMigrants\" target=\"_blank\">\n" \
"                            Infomigrants\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                                      " \
"                        \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"<a href=\"http://observers.france24.com/fr\" class=\"item-lo\" title=\"" \
"Les Observateurs\" target=\"_blank\">\n" \
"                            Les observateurs\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                                                                      " \
"                                                                      " \
"                        \n" \
"                                \n" \
"                                                \n" \
"\n" \
"                <li class=\"\">\n" \
"                                                                      " \
"                                                                      " \
"<a href=\"http://mashable.france24.com\" class=\"item-mash\" title=\"M" \
"ashable avec France 24\" target=\"_blank\">\n" \
"                            Mashable avec france 24\n" \
"                        </a>\n" \
"                                                                      " \
"              </li>\n" \
"                        </ul></nav></div>\n" \
"        <div class=\"page mini-player-context\">\n" \
"            <div id=\"loading\">\n" \
"\n" \
"                <div id=\"squaresWaveG\">\n" \
"                    <div id=\"squaresWaveG_1\" class=\"squaresWaveG\">" \
"\n" \
"                    </div>\n" \
"                    <div id=\"squaresWaveG_2\" class=\"squaresWaveG\">" \
"\n" \
"                    </div>\n" \
"                    <div id=\"squaresWaveG_3\" class=\"squaresWaveG\">" \
"\n" \
"                    </div>\n" \
"                    <div id=\"squaresWaveG_4\" class=\"squaresWaveG\">" \
"\n" \
"                    </div>\n" \
"                    <div id=\"squaresWaveG_5\" class=\"squaresWaveG\">" \
"\n" \
"                    </div>\n" \
"                    <div id=\"squaresWaveG_6\" class=\"squaresWaveG\">" \
"\n" \
"                    </div>\n" \
"                    <div id=\"squaresWaveG_7\" class=\"squaresWaveG\">" \
"\n" \
"                    </div>\n" \
"                    <div id=\"squaresWaveG_8\" class=\"squaresWaveG\">" \
"\n" \
"                    </div>\n" \
"                </div>\n" \
"\n" \
"            </div>\n" \
"                            <div class=\"on-air-board-outer\">\n" \
"    <div class=\"on-air-board\">\n" \
"        <div class=\"first-row\">\n" \
"                                                                      " \
"                                  <script type=\"application/json\" da" \
"ta-player-playlist=\"main-player\" data-player-bind=\"main-player\"><!" \
"[CDATA[\n" \
"    {\"medias\":{\"media\":{\"type\":\"video\",\"media_sources\":{\"me" \
"dia_source\":[{\"streaming_type\":{\"platforms\":{\"platform\":[\"flas" \
"h\",\"html5\"]},\"mime_type\":\"application\\/vnd.apple.mpegurl\",\"ty" \
"pe\":\"video\",\"html5_codec\":\"avc1.42E01E, mp3\",\"bitrate\":0},\"i" \
"s_default\":0,\"source\":\"http:\\/\\/static.france24.com\\/live\\/F24" \
"_FR_LO_HLS\\/live_web.m3u8\"}]},\"title\":\"\",\"is_live\":true,\"phot" \
"o_url\":\"\",\"thumbnail_url\":\"\",\"rolls\":{\"urlpre\":\"http:\\/\\" \
"/ad2play.ftv-publicite.fr\\/preroll.vast?v=2&sitepage=www.france24.fr\\" \
"/direct\",\"urlpost\":\"\"},\"is_active\":1,\"labels\":{\"now\":\"\"}," \
"\"comscore\":{\"baseMeasurementURL\":\"fr.sitestat.com\\/aef\\/f24-mcd" \
"-rfi\\/s?\",\"labels\":{\"ns_st_ci\":\"direct_france24\",\"ns_st_ep\":" \
"\"direct_france24\",\"ns_st_pr\":\"live\",\"ns_st_ty\":\"video\",\"ns_" \
"st_st\":\"france24_francais\",\"ns_st_pl\":\"france24_francais\",\"ns_" \
"st_el\":0,\"ns_st_ub\":0,\"ns_st_cn\":1,\"ns_st_cl\":0,\"ns_st_dt\":\"" \
"2016-01-13\",\"aef_streamtype_2\":\"live\",\"aef_rep_global\":\"live\"" \
",\"aef_type_page1\":\"player\",\"aef_type_contenu1\":\"video\",\"aef_s" \
"ection1\":\"live\",\"aef_auteur\":\"france24\",\"aef_dpubli\":\"2016-0" \
"1-13\",\"aef_hpubli\":\"14:37\",\"ns_st_li\":1,\"aef_marque\":\"france" \
"24\",\"name\":\"itemtype.defaut.defaut\",\"aef_type_environnement\":\"" \
"site\",\"aef_plateforme\":\"ordinateur\",\"aef_nom_environnement\":\"f" \
"rance24_site\",\"aef_version_environnement\":\"v1.36.9\",\"aef_perimet" \
"re_diffusion\":\"interne\",\"aef_url_provenance\":\"http:\\/\\/www.fra" \
"nce24.com\\/fr\\/\",\"aef_page_provenance\":\"\\/fr\\/\",\"aef_langue\"" \
":\"francais\",\"aef_acces\":\"gratuit\",\"aef_user_connection\":\"visi" \
"teur\",\"aef_user_id\":\"\"}}}}}\n" \
"]]></script><div id=\"dynamic-player-element\" class=\"async-load\" da" \
"ta-content=\"http://www.france24.com/fr/_fragment/player/tofollow/\">\n" \
"                    \n" \
"\n" \
"\n" \
"<a href=\"#\" class=\"player-live\" data-stream=\"main-player\" data-p" \
"layers-toggle=\"\">\n" \
"</a>\n" \
"\n" \
"<a href=\"#\" class=\"player-toggler\" data-youtube-id=\"\">\n" \
"    <span>&#xA0;</span>\n" \
"</a>\n" \
"\n" \
"<div/>\n" \
"\n" \
"    <div class=\"block\">\n" \
"        <h3>Rendez-vous</h3>\n" \
"        <div class=\"oab-rendez\"/>\n" \
"    </div>\n" \
"\n" \
"<div class=\"block\">\n" \
"    <h3>Rejouer</h3>\n" \
"    <ul class=\"oab-replay\"/></div>\n" \
"\n" \
"                </div>\n" \
"                <br style=\"clear: both; line-height: 0;\"/></div>\n" \
"\n" \
"        <div class=\"second-row\">\n" \
"            <div class=\"oab-first-col\">\n" \
"                                                <div class=\"video-pla" \
"yer\">\n" \
"                                        <div data-player-id=\"main-pla" \
"yer\" class=\"main-player\" data-player-duplication-id=\"main-player-y" \
"t\"/>\n" \
"                    <div data-ytplayer-id=\"main-player-yt\" class=\"m" \
"ain-player\" data-player-duplication-id=\"main-player\"/>\n" \
"                    <p class=\"copy\">\n" \
"                    </p><div data-fragment-src=\"http://www.france24.c" \
"om/fr/_fragment/player/nowplaying/\"/>\n" \
"                    \n" \
"                </div>\n" \
"                <div class=\"video-board\">\n" \
"                    <div class=\"v-header\"><h2>LES DERNI&#xC8;RES &#x" \
"C9;MISSIONS</h2></div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                   <di" \
"v class=\"v-item-2\" data-bo-type=\"edition\" data-bo-nid=\"WB5214082-" \
"F24-FR-20180105\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/edition/1801.pn" \
"g\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">MODE </p>\n" \
"                                        <h2 class=\"title\">La mode en" \
" 2017&#xA0;: f&#xE9;minisme, business et tabous &#xE0; briser</h2>\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:xVmbTxp2zK8" \
"\" data-players-video-title=\"MODE\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/20180105-mode-dior-lvmh-harcelement-maigreur-hyeres-barcelone-beyrout" \
"h-madrid-fashion-week\">En savoir plus</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"             <div class=\"v-item-2\" data-bo-type=\"edition\" data-bo-" \
"nid=\"WB5214076-F24-FR-20180105\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/edition/dls_rvp" \
"i_wsj.png.jpg\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">REVUE DE PR" \
"ESSE </p>\n" \
"                                        <h2 class=\"title\">Trump pour" \
" \"une expansion massive des forages p&#xE9;troliers offshore\"</h2>\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:d1xP867dis4" \
"\" data-players-video-title=\"REVUE DE PRESSE\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/20180105-offshore-etats-unis-trump-exploitation-hydrocarbures-avocate" \
"-ukrainienne-assassinat\">En savoir plus</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"             <div class=\"v-item-2\" data-bo-type=\"edition\" data-bo-" \
"nid=\"WB5214068-F24-FR-20180105\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/edition/dls_rvp" \
"_une_huma.png_1.jpg\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">REVUE DE PR" \
"ESSE </p>\n" \
"                                        <h2 class=\"title\">Erdogan en" \
" visite &#xE0; Paris&#xA0;: \"Le d&#xE9;jeuner qui fait grincer\"</h2>" \
"\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:bQHgoynC580" \
"\" data-players-video-title=\"REVUE DE PRESSE\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/20180105-erdogan-visite-paris-macron-droits-homme-purges-zad-carte-lo" \
"eb-dakar-perou\">En savoir plus</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"             <div class=\"v-item-2\" data-bo-type=\"edition\" data-bo-" \
"nid=\"WB5214050-F24-FR-20180105\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/edition/photo_e" \
"co_encadre_turquie.jpg\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">LE JOURNAL " \
"DE L'&#xC9;CO </p>\n" \
"                                        <h2 class=\"title\">Erdogan &#" \
"xE0; Paris, une visite aux accents &#xE9;conomiques</h2>\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:M3jovViFXdY" \
"\" data-players-video-title=\"LE JOURNAL DE L'&#xC9;CO\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/20180105-turquie-erdogan-france-cuba-mogherini-moneygram-or-air-franc" \
"e-spotify-galette\">En savoir plus</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"             <div class=\"v-item-2\" data-bo-type=\"edition\" data-bo-" \
"nid=\"WB5213972-F24-FR-20180104\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/edition/salah-m" \
"ohamed-ballon-dor-africain_ok.jpeg\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">LE JOURNAL " \
"DE L&#x2019;AFRIQUE </p>\n" \
"                                        <h2 class=\"title\">L'&#xC9;gy" \
"ptien Mohamed Salah sacr&#xE9; Joueur africain de l'ann&#xE9;e</h2>\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:uW9fR1zqMCQ" \
"\" data-players-video-title=\"LE JOURNAL DE L&#x2019;AFRIQUE\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/20180104-mohamed-salah-joueur-africain-annee-rdc-eglise-catholique-to" \
"go-gnassingbe\">En savoir plus</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"             <div class=\"v-item-2\" data-bo-type=\"edition\" data-bo-" \
"nid=\"WB5213964-F24-FR-20180104\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/2018-01-04_2221" \
"_un_oeil_sur_les_medias.jpeg\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">UN &#x152;I" \
"L SUR LES M&#xC9;DIAS </p>\n" \
"                                        <h2 class=\"title\">Emmanuel M" \
"acron d&#xE9;clare la guerre aux \"Fake News\"</h2>\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:I9Ev83CpSTI" \
"\" data-players-video-title=\"UN &#x152;IL SUR LES M&#xC9;DIAS\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/oeil-medias/20180104-emmanuel-macron-declare-a-guerre-fake-news\">En " \
"savoir plus</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"             <div class=\"v-item-2\" data-bo-type=\"edition\" data-bo-" \
"nid=\"WB5213929-F24-FR-20180104\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/edition/debat_4" \
"3.jpg\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">LE D&#xC9;B" \
"AT </p>\n" \
"                                        <h2 class=\"title\">Diplomatie" \
" fran&#xE7;aise : Emmanuel Macron, changement de style ou changement d" \
"e fond ? (partie 2)</h2>\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:-3pkJVuQgbQ" \
"\" data-players-video-title=\"LE D&#xC9;BAT\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/20180104-le-debat-emmanuel-macron-diplomatie-francaise-partie-2\">En " \
"savoir plus</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"             <div class=\"v-item-2\" data-bo-type=\"edition\" data-bo-" \
"nid=\"WB5213928-F24-FR-20180104\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/edition/debat_4" \
"2.jpg\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">LE D&#xC9;B" \
"AT </p>\n" \
"                                        <h2 class=\"title\">Diplomatie" \
" fran&#xE7;aise : Emmanuel Macron, changement de style ou changement d" \
"e fond ? (partie 1)</h2>\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:9tGoUCa_HBA" \
"\" data-players-video-title=\"LE D&#xC9;BAT\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/20180104-le-debat-emmanuel-macron-diplomatie-francaise\">En savoir pl" \
"us</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"             <div class=\"v-item-2\" data-bo-type=\"edition\" data-bo-" \
"nid=\"WB5213822-F24-FR-20180104\">\n" \
"                                    <div class=\"media video\">\n" \
"                                        <img src=\"http://scd.france24" \
".com/fr/files_fr/imagecache/france24_ct_api_medium_169/edition/rwanda_" \
"evangelicals_focus.jpg\" alt=\"\"/></div>\n" \
"                                    <div class=\"copy\">\n" \
"                                        <p class=\"place\">FOCUS </p>\n" \
"                                        <h2 class=\"title\">Le Rwanda " \
"en plein \"r&#xE9;veil\" &#xE9;vang&#xE9;lique</h2>\n" \
"                                    </div>\n" \
"                                    <p class=\"default-read-more\" sty" \
"le=\"\" data-players-toggle=\"main-player-yt.loadVideoById:bg9camAClZU" \
"\" data-players-video-title=\"FOCUS\">\n" \
"                                        <a rel=\"nofollow\" href=\"/fr" \
"/2018-01-04-focus-rwanda-evangeliques-religion-eglises-catholiques\">E" \
"n savoir plus</a>\n" \
"                                    </p>\n" \
"                                </div>\n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"           <script type=\"application/json\" data-player-playlist=\"ed" \
"ition-WB5213751-F24-FR-20180104\" data-player-bind=\"main-player\" dat" \
"a-player-playlist-default=\"\"><![CDATA[\n" \
"    {\"medias\":{\"media\":{\"type\":\"video\",\"media_sources\":{\"me" \
"dia_source\":[{\"streaming_type\":{\"platforms\":{\"platform\":[\"flas" \
"h\",\"html5\"]},\"mime_type\":\"video\\/mp4\",\"type\":\"video\",\"htm" \
"l5_codec\":\"avc1.42E01E, mp3\",\"bitrate\":0},\"is_default\":0,\"sour" \
"ce\":\"http:\\/\\/medias.france24.com\\/fr\\/vod\\/2018\\/01\\/04\\/FR" \
"AN180104-0916-Live_CS0916.mp4\"}]},\"title\":\"\",\"is_live\":0,\"phot" \
"o_url\":\"\",\"thumbnail_url\":\"\",\"rolls\":{\"urlpre\":\"\",\"urlpo" \
"st\":\"\"},\"is_active\":1,\"labels\":{\"now\":\"\"},\"comscore\":{\"b" \
"aseMeasurementURL\":\"fr.sitestat.com\\/aef\\/f24-mcd-rfi\\/s?\",\"lab" \
"els\":{\"ns_st_ci\":\"WB5213751-F24-FR-20180104\",\"ns_st_ep\":\"L'Uni" \
"on europ\\u00e9enne renforce ses liens avec Cuba\",\"ns_st_pr\":\"fr\"" \
",\"ns_st_ty\":\"video\",\"ns_st_st\":\"france24_francais\",\"ns_st_pl\"" \
":\"france24_francais\",\"ns_st_el\":0,\"ns_st_ub\":0,\"ns_st_cn\":1,\"" \
"ns_st_cl\":0,\"ns_st_dt\":\"2016-01-13\",\"aef_streamtype_2\":\"od\",\"" \
"aef_rep_global\":\"live\",\"aef_type_page1\":\"player\",\"aef_type_con" \
"tenu1\":\"video\",\"aef_section1\":\"live\",\"aef_auteur\":\"france24\"" \
",\"aef_dpubli\":\"2016-01-13\",\"aef_hpubli\":\"14:37\",\"ns_st_li\":1" \
",\"aef_marque\":\"france24\",\"name\":\"itemtype.defaut.defaut\",\"aef" \
"_type_environnement\":\"site\",\"aef_plateforme\":\"ordinateur\",\"aef" \
"_nom_environnement\":\"france24_site\",\"aef_version_environnement\":\"" \
"v1.36.9\",\"aef_perimetre_diffusion\":\"interne\",\"aef_url_provenance" \
"\":\"http:\\/\\/www.france24.com\\/fr\\/\",\"aef_page_provenance\":\"\\" \
"/fr\\/\",\"aef_langue\":\"francais\",\"aef_acces\":\"gratuit\",\"aef_u" \
"ser_connection\":\"visiteur\",\"aef_user_id\":\"\"}}}}}\n" \
"]]></script><div class=\"v-expand-items\">\n" \
"                        <a href=\"/fr/emissions/\" class=\"default-but" \
"ton-1 modeless\" title=\"Derni&#xE8;res &#xE9;missions\">\n" \
"                            Toutes les &#xE9;missions\n" \
"                        </a>\n" \
"                    </div>\n" \
"                </div>\n" \
"            </div>\n" \
"\n" \
"            <div class=\"oab-second-col\">\n" \
"                <div class=\"program-schedule\">\n" \
"                    <div class=\"hd\">\n" \
"                        <div class=\"type-1\">\n" \
"                            <a href=\"#\" class=\"tabs\" data-target=\"" \
"player-comments\">\n" \
"                                <span class=\"comment-count\">\n" \
"                                                                      " \
"  \n" \
"            <span class=\"fb-comments-count\" data-href=\"http://www.f" \
"rance24.com/fr/?query=player-live\"/>\n" \
"    \n" \
"                                </span>\n" \
"                                COMMENTAIRE(S)\n" \
"                            </a>\n" \
"                            <a href=\"#\" class=\"tabs active\" data-t" \
"arget=\"player-programs\">Grille des programmes</a>\n" \
"                        </div>\n" \
"                        <div class=\"type-2\">\n" \
"                            <a href=\"#\" class=\"comm tabs\" data-tar" \
"get=\"player-comments\">\n" \
"                                <span class=\"comment-count\">\n" \
"                                    \n" \
"            <span class=\"fb-comments-count\" data-href=\"http://www.f" \
"rance24.com/fr/?query=player-live\"/>\n" \
"    \n" \
"                                </span>\n" \
"                                &#xA0;commentaires\n" \
"                            </a>\n" \
"                            <a href=\"#\" class=\"pro tabs active\" da" \
"ta-target=\"player-programs\">\n" \
"                                <span/>Programmes\n" \
"                            </a>\n" \
"                        </div>\n" \
"                    </div>\n" \
"                    <div id=\"player-comments\" class=\"bd tabs\" styl" \
"e=\"display: none\">                                                \n" \
"            <div class=\"facebook-comment\">\n" \
"                                    <div class=\"fb-comments\" data-hr" \
"ef=\"http://www.france24.com/fr/?query=player-live\" width=\"100%\" da" \
"ta-numposts=\"5\" data-colorscheme=\"light\" data-mobile=\"false\"/>\n" \
"                    </div>\n" \
"    \n" \
"                    </div>\n" \
"                    <div id=\"player-programs\" class=\"bd tabs\">\n" \
"                        <div data-fragment-src=\"http://www.france24.c" \
"om/fr/_fragment/player/programgrid/\"/>\n" \
"                    </div>\n" \
"                </div>\n" \
"            </div>\n" \
"        </div>\n" \
"    </div>\n" \
"</div>\n" \
"\n" \
"                                    <div class=\"slider-wrap\">\n" \
"                <div class=\"content-slider\">\n" \
"                    <div class=\"content-slide\">\n" \
"                        <div class=\"main-board emission-board\">\n" \
"                                                                      " \
"                  \n" \
"    <div class=\"adv-megaban tms-block\" data-pos=\"1\" data-type=\"me" \
"gaban\" data-location=\"top\" data-expand=\"true\" data-loaded=\"false" \
"\">\n" \
"    </div>\n" \
"\n" \
"\n" \
"                                                        <div id=\"mode" \
"less-target\" data-fb-no-comments=\"Laisser un commentaire\">\n" \
"                                            <a href=\"/fr/emissions/el" \
"ement-terre/\">\n" \
"        <div class=\"section-banner\" data-bo-type=\"emission\" data-b" \
"o-nid=\"287F6962-3E2B-4232-B35F-B709BF190D84\">\n" \
"            <div class=\"image-banner\">\n" \
"                                <img src=\"http://scd.france24.com/fr/" \
"files_fr/ELEMENT_TERRE_FR_0.jpg\" alt=\"&#xC9;L&#xC9;MENT TERRE\"/></d" \
"iv>\n" \
"            <div class=\"intro-banner\">\n" \
"                <p> Ouvrons les yeux sur le monde qui nous entoure! Ai" \
"d&#xE9;s par une &#xE9;quipe de graphistes, nous d&#xE9;poussi&#xE9;ro" \
"ns et d&#xE9;cortiquons les grands th&#xE8;mes qui font l&#x2019;envir" \
"onnement aujourd&#x2019;hui. Le samedi &#xE0; 20h20. Et d&#xE8;s le ve" \
"ndredi en avant-premi&#xE8;re sur internet! </p>\n" \
"            </div>\n" \
"        </div>\n" \
"    </a>\n" \
"        <div class=\"col-1 highfooter\">\n" \
"\n" \
"                <article class=\"article-long\" data-bo-type=\"edition" \
"\" data-bo-nid=\"WB5190871-F24-FR-20171018\"><header class=\"hd\"><ul " \
"class=\"tag\"><li><a href=\"/fr/tag/chine/\" title=\"Chine\" class=\"m" \
"odeless\">Chine</a></li>\n" \
"                            <li><a href=\"/fr/tag/climat/\" title=\"Cl" \
"imat\" class=\"modeless\">Climat</a></li>\n" \
"                            <li><a href=\"/fr/tag/energies-renouvelabl" \
"es/\" title=\"&#xC9;nergies renouvelables\" class=\"modeless\">&#xC9;n" \
"ergies renouvelables</a></li>\n" \
"                        </ul><p class=\"modification\">Derni&#xE8;re m" \
"odification : 20/10/2017</p>\n" \
"                <h1 class=\"title\">Climat&#xA0;: la Chine est-elle le" \
" nouveau leader ?</h1>\n" \
"\n" \
"                <div class=\"article-action emission-action\">\n" \
"                    <div class=\"emission_title\">\n" \
"                                                                      " \
"                          <a class=\"icon-rss\" target=\"_blank\" href" \
"=\"/fr/emissions/element-terre/podcast\"/>\n" \
"                        <a class=\"icon-podcast\" target=\"_blank\" hr" \
"ef=\"itpc://www.france24.com/fr/emissions/element-terre/podcast\"/>\n" \
"                    </div>\n" \
"                    \n" \
"<script type=\"text/javascript\"><![CDATA[\n" \
"    function linkedInSuccess(data) {\n" \
"        trackingSocial.li_tracker();\n" \
"    }\n" \
"]]></script><ul class=\"sharebar-social-part\"><li class=\"social-cell" \
" fb\">\n" \
"                        <div class=\"fb-share-button\" data-href=\"htt" \
"p://f24.my/1yc3.F\" data-type=\"button_count\" data-width=\"90\" data-" \
"callback=\"trackingSocial.fb_tracker\"/>\n" \
"        </li>\n" \
"    \n" \
"            <li class=\"social-cell tt\">\n" \
"            <a href=\"https://twitter.com/share\" class=\"twitter-shar" \
"e-button\" data-url=\"http://f24.my/1yc3.T\" data-counturl=\"http://ww" \
"w.france24.com/fr/20171021-chine-charbon-centrale-etranger-energie-env" \
"ironnement-leader-climat\" data-text=\"&#xC9;L&#xC9;MENT TERRE - Clima" \
"t&#xA0;: la Chine est-elle le nouveau leader ?\" data-via=\"\" data-la" \
"ng=\"fr\" data-related=\"France24_fr\" data-callback=\"trackingSocial." \
"tt_tracker\">Tweeter</a>\n" \
"        </li>\n" \
"    \n" \
"            <li class=\"social-cell gg\">\n" \
"            <div class=\"g-plus\" data-action=\"share\" data-annotatio" \
"n=\"bubble\" data-href=\"http://www.france24.com/fr/20171021-chine-cha" \
"rbon-centrale-etranger-energie-environnement-leader-climat\" data-call" \
"back=\"trackingSocial.gg_tracker\"/>\n" \
"        </li>\n" \
"    \n" \
"    \n" \
"            <li class=\"social-cell in\">\n" \
"            <script type=\"IN/Share\" data-url=\"http://f24.my/1yc3.L\"" \
" data-counter=\"right\" data-onsuccess=\"liTracker\"/></li>\n" \
"    </ul><ul class=\"sharebar-internal-part\"/><div class=\"clear-both" \
"\"/>\n" \
"\n" \
"\n" \
"                </div>\n" \
"\n" \
"                                \n" \
"                <figure class=\"img\"><div style=\"background-image: u" \
"rl('http://scd.france24.com/fr/files_fr/imagecache/france24_ct_api_big" \
"ger_169/edition/fr_element_terre_chine_charbon_pad.sub_.01.jpg'); back" \
"ground-size: cover\" data-ytplayer-id=\"15oDkx7jjvU\" class=\"youtube-" \
"container bsplayer-type-video bsplayer-processed\"/>\n" \
"                                                                      " \
"                                          <figcaption>&#xA9; Capture F" \
"rance 24</figcaption></figure></header><div class=\"bd\">\n" \
"                <h2>Autrefois mauvaise &#xE9;l&#xE8;ve des n&#xE9;goci" \
"ations climatiques, la Chine a chang&#xE9; de cap. D&#xE9;sormais, P&#" \
"xE9;kin investit massivement dans les &#xE9;nergies renouvelables et p" \
"articipe &#xE0; l&#x2019;effort collectif, occupant la chaise vide lai" \
"ss&#xE9;e par les &#xC9;tats-Unis de Donald Trump. Mais par ailleurs, " \
"des entreprises publiques chinoises sont li&#xE9;es &#xE0; une centain" \
"e de projets de centrales &#xE0; charbon &#xE0; l'&#xE9;tranger. La Ch" \
"ine peut-elle tout de m&#xEA;me &#xEA;tre consid&#xE9;r&#xE9;e comme u" \
"n h&#xE9;ros du climat ? Ou joue-t-elle un double jeu&#xA0;?</h2>\n" \
"                <p>La Chine poursuit sa politique charbon &#xE0; l&#x2" \
"019;&#xE9;tranger. Des entreprises publiques chinoises sont li&#xE9;es" \
" &#xE0; une centaine de projets de centrales &#xE0; charbon dans 27 pa" \
"ys &#xE9;trangers. Alors, la Chine joue-t-elle double jeu ?</p>\n" \
"                                    <p class=\"author\">\n" \
"                        Par <a title=\"Marina BERTSCH\" class=\"modele" \
"ss\" href=\"/fr/auteur/marina-bertsch/\">Marina BERTSCH</a>\n" \
"                                                    , <a title=\"Maire" \
"ad DUNDAS\" class=\"modeless\" href=\"/fr/auteur/mairead-dundas/\">Mai" \
"read DUNDAS</a>\n" \
"                                                    , <a title=\"Julie" \
"tte LACHARNAY\" class=\"modeless\" href=\"/fr/auteur/juliette-lacharna" \
"y/\">Juliette LACHARNAY</a>\n" \
"                                                    , <a title=\"Val&#" \
"xE9;rie DEKIMPE\" class=\"modeless\" href=\"/fr/auteur/valerie-dekimpe" \
"/\">Val&#xE9;rie DEKIMPE</a>\n" \
"                                                                    </" \
"p>\n" \
"                            </div>\n" \
"            \n" \
"                        <div class=\"clear-both\"/>\n" \
"\n" \
"                                    <div class=\"clear-both\"/>\n" \
"        </article><div class=\"article-action\">\n" \
"            \n" \
"<script type=\"text/javascript\"><![CDATA[\n" \
"    function linkedInSuccess(data) {\n" \
"        trackingSocial.li_tracker();\n" \
"    }\n" \
"]]></script><ul class=\"sharebar-social-part\"><li class=\"social-cell" \
" fb\">\n" \
"                        <div class=\"fb-share-button\" data-href=\"htt" \
"p://f24.my/1yc3.F\" data-type=\"button_count\" data-width=\"90\" data-" \
"callback=\"trackingSocial.fb_tracker\"/>\n" \
"        </li>\n" \
"    \n" \
"            <li class=\"social-cell tt\">\n" \
"            <a href=\"https://twitter.com/share\" class=\"twitter-shar" \
"e-button\" data-url=\"http://f24.my/1yc3.T\" data-counturl=\"http://ww" \
"w.france24.com/fr/20171021-chine-charbon-centrale-etranger-energie-env" \
"ironnement-leader-climat\" data-text=\"&#xC9;L&#xC9;MENT TERRE - Clima" \
"t&#xA0;: la Chine est-elle le nouveau leader ?\" data-via=\"\" data-la" \
"ng=\"fr\" data-related=\"France24_fr\" data-callback=\"trackingSocial." \
"tt_tracker\">Tweeter</a>\n" \
"        </li>\n" \
"    \n" \
"            <li class=\"social-cell gg\">\n" \
"            <div class=\"g-plus\" data-action=\"share\" data-annotatio" \
"n=\"bubble\" data-href=\"http://www.france24.com/fr/20171021-chine-cha" \
"rbon-centrale-etranger-energie-environnement-leader-climat\" data-call" \
"back=\"trackingSocial.gg_tracker\"/>\n" \
"        </li>\n" \
"    \n" \
"    \n" \
"            <li class=\"social-cell in\">\n" \
"            <script type=\"IN/Share\" data-url=\"http://f24.my/1yc3.L\"" \
" data-counter=\"right\" data-onsuccess=\"liTracker\"/></li>\n" \
"    </ul><ul class=\"sharebar-internal-part\"/><div class=\"clear-both" \
"\"/>\n" \
"\n" \
"\n" \
"        </div>\n" \
"\n" \
"                            \n" \
"                                    <div class=\"footage-board vertica" \
"l-position\">\n" \
"        <h5 class=\"default-header-2\">Les archives</h5>\n" \
"                    <div class=\"news-item no-0\" data-bo-type=\"editi" \
"on\" data-bo-nid=\"WB5208883-F24-FR-20171214\">\n" \
"            <div class=\"media video\">\n" \
"                                                \n" \
"                <img src=\"http://scd.france24.com/fr/files_fr/imageca" \
"che/hermes_infographie_vignette_home/edition/emission_year_in_review_1" \
".jpg\" alt=\"\"/><span/>\n" \
"            </div>\n" \
"\n" \
"                                    \n" \
"            <div class=\"copy\">\n" \
"                <p class=\"meta\">14/12/2017 R&#xE9;chauffement climat" \
"ique</p>\n" \
"                <h3 class=\"title\">\n" \
"                    <a title=\"2017, ann&#xE9;e catastrophique pour l&" \
"#x2019;environnement ?\" href=\"/fr/20171216-pire-annee-2017-environne" \
"ment-climat-catastrophes-naturelles-ouragans-trump-accord-paris\" clas" \
"s=\"modeless\">\n" \
"                        2017, ann&#xE9;e catastrophique pour l&#x2019;" \
"environnement ?\n" \
"                    </a>\n" \
"                </h3>\n" \
"                <p class=\"desc\">\n" \
"                   Inondations, ouragans, s&#xE9;cheresse, feux de for" \
"&#xEA;t, temp&#xE9;ratures extr&#xEA;mes, &#xE9;missions de Co2 en aug" \
"mentation : 2017 a &#xE9;t&#xE9; un cru exceptionnellement mauvais, ba" \
"ttant mois apr&#xE8;s mois...\n" \
"                </p>\n" \
"            </div>\n" \
"\n" \
"                                        \n" \
"            <ul class=\"social-nt\"><li class=\"target\">\n" \
"                    <div>\n" \
"                        <img alt=\"Partager\" width=\"32\" height=\"32" \
"\" src=\"/bundles/aefhermesf24/img/01.png?version=20171213121500\"/></" \
"div>\n" \
"                </li>\n" \
"                <li class=\"item\"><div class=\"fb fb-share\" data-hre" \
"f=\"http://f24.my/2F7g.F\" data-callback=\"trackingSocial.fb_tracker\"" \
" data-title=\"2017, ann&#xE9;e catastrophique pour l&#x2019;environnem" \
"ent ?\"/></li>\n" \
"                <li class=\"item\"><div class=\"tw tt-share\" data-hre" \
"f=\"http://f24.my/2F7g.T\" data-callback=\"trackingSocial.tt_tracker\"" \
" data-text=\"2017, ann&#xE9;e catastrophique pour l&#x2019;environneme" \
"nt ?\"/></li>\n" \
"                <li class=\"item\"><div class=\"go gg-share\" data-hre" \
"f=\"http://www.france24.com/fr/20171216-pire-annee-2017-environnement-" \
"climat-catastrophes-naturelles-ouragans-trump-accord-paris\" data-call" \
"back=\"trackingSocial.gg_tracker\"/></li>\n" \
"                <li class=\"item\"><div class=\"li in-share\" data-hre" \
"f=\"http://f24.my/2F7g.L\" data-callback=\"trackingSocial.in_tracker\"" \
" data-title=\"2017, ann&#xE9;e catastrophique pour l&#x2019;environnem" \
"ent ?\"/></li>\n" \
"            </ul><p class=\"default-read-more\">\n" \
"                <a rel=\"nofollow\" title=\"http://www.france24.com/fr" \
"/20171216-pire-annee-2017-environnement-climat-catastrophes-naturelles" \
"-ouragans-trump-accord-paris\" href=\"/fr/20171216-pire-annee-2017-env" \
"ironnement-climat-catastrophes-naturelles-ouragans-trump-accord-paris\"" \
" class=\"modeless\">En savoir plus</a>\n" \
"            </p>\n" \
"        </div>\n" \
"\n" \
"                                                    <div class=\"news-" \
"item no-0\" data-bo-type=\"edition\" data-bo-nid=\"WB5204867-F24-FR-20" \
"171201\">\n" \
"            <div class=\"media video\">\n" \
"                                                \n" \
"                <img src=\"http://scd.france24.com/fr/files_fr/imageca" \
"che/hermes_infographie_vignette_home/edition/en_element_terre_virage_v" \
"ert.jpg\" alt=\"\"/><span/>\n" \
"            </div>\n" \
"\n" \
"                                    \n" \
"            <div class=\"copy\">\n" \
"                <p class=\"meta\">01/12/2017 P&#xE9;trole</p>\n" \
"                <h3 class=\"title\">\n" \
"                    <a title=\"Le virage vert des p&#xE9;troliers, inf" \
"o ou intox&#xA0;?\" href=\"/fr/20171202-elementerre-petroliers-investi" \
"ssements-energies-renouvelables-virage-vert-total\" class=\"modeless\"" \
">\n" \
"                        Le virage vert des p&#xE9;troliers, info ou in" \
"tox&#xA0;?\n" \
"                    </a>\n" \
"                </h3>\n" \
"                <p class=\"desc\">\n" \
"                   Total, Shell, Statoil, l'Arabie Saoudite... Les g&#" \
"xE9;ants du p&#xE9;trole annoncent des milliards de dollars d'investis" \
"sements dans les &#xE9;nergies renouvelables. Nous avons voulu savoir." \
"..\n" \
"                </p>\n" \
"            </div>\n" \
"\n" \
"                                        \n" \
"            <ul class=\"social-nt\"><li class=\"target\">\n" \
"                    <div>\n" \
"                        <img alt=\"Partager\" width=\"32\" height=\"32" \
"\" src=\"/bundles/aefhermesf24/img/01.png?version=20171213121500\"/></" \
"div>\n" \
"                </li>\n" \
"                <li class=\"item\"><div class=\"fb fb-share\" data-hre" \
"f=\"http://f24.my/2B88.F\" data-callback=\"trackingSocial.fb_tracker\"" \
" data-title=\"Le virage vert des p&#xE9;troliers, info ou intox&#xA0;?" \
"\"/></li>\n" \
"                <li class=\"item\"><div class=\"tw tt-share\" data-hre" \
"f=\"http://f24.my/2B88.T\" data-callback=\"trackingSocial.tt_tracker\"" \
" data-text=\"Le virage vert des p&#xE9;troliers, info ou intox&#xA0;?\"" \
"/></li>\n" \
"                <li class=\"item\"><div class=\"go gg-share\" data-hre" \
"f=\"http://www.france24.com/fr/20171202-elementerre-petroliers-investi" \
"ssements-energies-renouvelables-virage-vert-total\" data-callback=\"tr" \
"ackingSocial.gg_tracker\"/></li>\n" \
"                <li class=\"item\"><div class=\"li in-share\" data-hre" \
"f=\"http://f24.my/2B88.L\" data-callback=\"trackingSocial.in_tracker\"" \
" data-title=\"Le virage vert des p&#xE9;troliers, info ou intox&#xA0;?" \
"\"/></li>\n" \
"            </ul><p class=\"default-read-more\">\n" \
"                <a rel=\"nofollow\" title=\"http://www.france24.com/fr" \
"/20171202-elementerre-petroliers-investissements-energies-renouvelable" \
"s-virage-vert-total\" href=\"/fr/20171202-elementerre-petroliers-inves" \
"tissements-energies-renouvelables-virage-vert-total\" class=\"modeless" \
"\">En savoir plus</a>\n" \
"            </p>\n" \
"        </div>\n" \
"\n" \
"                                                    <div class=\"news-" \
"item no-0\" data-bo-type=\"edition\" data-bo-nid=\"WB5200175-F24-FR-20" \
"171116\">\n" \
"            <div class=\"media video\">\n" \
"                                                \n" \
"                <img src=\"http://scd.france24.com/fr/files_fr/imageca" \
"che/hermes_infographie_vignette_home/edition/saumon_norvege.jpg\" alt=" \
"\"\"/><span/>\n" \
"            </div>\n" \
"\n" \
"                                    \n" \
"            <div class=\"copy\">\n" \
"                <p class=\"meta\">16/11/2017 Norv&#xE8;ge</p>\n" \
"                <h3 class=\"title\">\n" \
"                    <a title=\"Saumon de Norv&#xE8;ge : la guerre du p" \
"ou est d&#xE9;clar&#xE9;e \" href=\"/fr/20171118-norvege-saumon-indust" \
"rie-parasite-poux-mer-innovation\" class=\"modeless\">\n" \
"                        Saumon de Norv&#xE8;ge : la guerre du pou est " \
"d&#xE9;clar&#xE9;e \n" \
"                    </a>\n" \
"                </h3>\n" \
"                <p class=\"desc\">\n" \
"                   &#xC0; une &#xE9;poque, le saumon &#xE9;tait un poi" \
"sson luxueux, r&#xE9;serv&#xE9; aux tables de No&#xEB;l. Aujourd&#x201" \
"9;hui, il est devenu un plat du quotidien. La croissance de ce march&#" \
"xE9; est vertigineuse. On...\n" \
"                </p>\n" \
"            </div>\n" \
"\n" \
"                                        \n" \
"            <ul class=\"social-nt\"><li class=\"target\">\n" \
"                    <div>\n" \
"                        <img alt=\"Partager\" width=\"32\" height=\"32" \
"\" src=\"/bundles/aefhermesf24/img/01.png?version=20171213121500\"/></" \
"div>\n" \
"                </li>\n" \
"                <li class=\"item\"><div class=\"fb fb-share\" data-hre" \
"f=\"http://f24.my/2703.F\" data-callback=\"trackingSocial.fb_tracker\"" \
" data-title=\"Saumon de Norv&#xE8;ge : la guerre du pou est d&#xE9;cla" \
"r&#xE9;e \"/></li>\n" \
"                <li class=\"item\"><div class=\"tw tt-share\" data-hre" \
"f=\"http://f24.my/2703.T\" data-callback=\"trackingSocial.tt_tracker\"" \
" data-text=\"Saumon de Norv&#xE8;ge : la guerre du pou est d&#xE9;clar" \
"&#xE9;e \"/></li>\n" \
"                <li class=\"item\"><div class=\"go gg-share\" data-hre" \
"f=\"http://www.france24.com/fr/20171118-norvege-saumon-industrie-paras" \
"ite-poux-mer-innovation\" data-callback=\"trackingSocial.gg_tracker\"/" \
"></li>\n" \
"                <li class=\"item\"><div class=\"li in-share\" data-hre" \
"f=\"http://f24.my/2703.L\" data-callback=\"trackingSocial.in_tracker\"" \
" data-title=\"Saumon de Norv&#xE8;ge : la guerre du pou est d&#xE9;cla" \
"r&#xE9;e \"/></li>\n" \
"            </ul><p class=\"default-read-more\">\n" \
"                <a rel=\"nofollow\" title=\"http://www.france24.com/fr" \
"/20171118-norvege-saumon-industrie-parasite-poux-mer-innovation\" href" \
"=\"/fr/20171118-norvege-saumon-industrie-parasite-poux-mer-innovation\"" \
" class=\"modeless\">En savoir plus</a>\n" \
"            </p>\n" \
"        </div>\n" \
"\n" \
"                                                    <div class=\"news-" \
"item no-0\" data-bo-type=\"edition\" data-bo-nid=\"WB5195708-F24-FR-20" \
"171102\">\n" \
"            <div class=\"media video\">\n" \
"                                                \n" \
"                <img src=\"http://scd.france24.com/fr/files_fr/imageca" \
"che/hermes_infographie_vignette_home/edition/nucleaire_sans_texte_pad." \
"jpg\" alt=\"\"/><span/>\n" \
"            </div>\n" \
"\n" \
"                                    \n" \
"            <div class=\"copy\">\n" \
"                <p class=\"meta\">02/11/2017 &#xC9;nergie nucl&#xE9;ai" \
"re</p>\n" \
"                <h3 class=\"title\">\n" \
"                    <a title=\"Nucl&#xE9;aire : on fait quoi des d&#xE" \
"9;chets ?\" href=\"/fr/20171104-nucleaire-dechets-radioactifs-france-h" \
"ague-bure-enfouissement\" class=\"modeless\">\n" \
"                        Nucl&#xE9;aire : on fait quoi des d&#xE9;chets" \
" ?\n" \
"                    </a>\n" \
"                </h3>\n" \
"                <p class=\"desc\">\n" \
"                   La France est le royaume du nucl&#xE9;aire. L&#x201" \
"9;industrie &#xE9;met peu de Co2, mais les d&#xE9;chets qu&#x2019;elle" \
" produit sont un casse-t&#xEA;te sans solution &#xE0; long terme. \n" \
"                </p>\n" \
"            </div>\n" \
"\n" \
"                                        \n" \
"            <ul class=\"social-nt\"><li class=\"target\">\n" \
"                    <div>\n" \
"                        <img alt=\"Partager\" width=\"32\" height=\"32" \
"\" src=\"/bundles/aefhermesf24/img/01.png?version=20171213121500\"/></" \
"div>\n" \
"                </li>\n" \
"                <li class=\"item\"><div class=\"fb fb-share\" data-hre" \
"f=\"http://f24.my/22pU.F\" data-callback=\"trackingSocial.fb_tracker\"" \
" data-title=\"Nucl&#xE9;aire : on fait quoi des d&#xE9;chets ?\"/></li" \
">\n" \
"                <li class=\"item\"><div class=\"tw tt-share\" data-hre" \
"f=\"http://f24.my/22pU.T\" data-callback=\"trackingSocial.tt_tracker\"" \
" data-text=\"Nucl&#xE9;aire : on fait quoi des d&#xE9;chets ?\"/></li>" \
"\n" \
"                <li class=\"item\"><div class=\"go gg-share\" data-hre" \
"f=\"http://www.france24.com/fr/20171104-nucleaire-dechets-radioactifs-" \
"france-hague-bure-enfouissement\" data-callback=\"trackingSocial.gg_tr" \
"acker\"/></li>\n" \
"                <li class=\"item\"><div class=\"li in-share\" data-hre" \
"f=\"http://f24.my/22pU.L\" data-callback=\"trackingSocial.in_tracker\"" \
" data-title=\"Nucl&#xE9;aire : on fait quoi des d&#xE9;chets ?\"/></li" \
">\n" \
"            </ul><p class=\"default-read-more\">\n" \
"                <a rel=\"nofollow\" title=\"http://www.france24.com/fr" \
"/20171104-nucleaire-dechets-radioactifs-france-hague-bure-enfouissemen" \
"t\" href=\"/fr/20171104-nucleaire-dechets-radioactifs-france-hague-bur" \
"e-enfouissement\" class=\"modeless\">En savoir plus</a>\n" \
"            </p>\n" \
"        </div>\n" \
"\n" \
"                                                            <div class" \
"=\"f-expand-items\">\n" \
"            <a href=\"/fr/emissions/element-terre/\" title=\"element-t" \
"erre\" class=\"default-button-1 modeless\">Voir toutes les archives</a" \
">\n" \
"        </div>\n" \
"    </div>\n" \
"\n" \
"                    \n" \
"    </div>\n" \
"\n" \
"        <aside class=\"col-2\"><div class=\"equipe\">\n" \
"        <div class=\"persons\">\n" \
"                                <div class=\"person\">\n" \
"                <div>\n" \
"                                        <figure><img src=\"http://scd." \
"france24.com/fr/files_fr/author_pictures/marina_bertsch.jpg\" alt=\"\"" \
" width=\"213\"/><figcaption><strong>MARINA BERTSCH</strong>\n" \
"                            <cite>Journaliste &#xE0; France 24, sp&#xE" \
"9;cialiste des questions d&#x2019;environnement</cite>\n" \
"                        </figcaption></figure><a href=\"https://twitte" \
"r.com/greenF24\" class=\"twitter-follow-button\" data-show-count=\"fal" \
"se\" data-show-screen-name=\"false\" data-lang=\"fr\">\n" \
"                                </a>\n" \
"                                                                      " \
"                      <p>\n" \
"                       </p><p>Dipl&#xF4;m&#xE9;e de Sciences Po Paris " \
"et du CFJ, elle a travaill&#xE9; pour France 3 et France 5, avant de r" \
"ejoindre FRANCE 24 &#xE0; sa cr&#xE9;ation, en 2006. Elle est sp&#xE9;" \
"cialiste des questions d&#x2019;environnement.</p>\n" \
"                                            \n" \
"                </div>\n" \
"            </div>\n" \
"                            </div>\n" \
"    </div>\n" \
"    \n" \
"                                                    \n" \
"    <div class=\"ib-adv tms-block\" data-pos=\"1\" data-type=\"pave\" " \
"data-location=\"sidebar\" data-expand=\"true\" data-loaded=\"false\">\n" \
"    </div>\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"    <div class=\"emissions-list shadow-section\">\n" \
"        <h5>Nos &#xE9;missions</h5>\n" \
"\n" \
"                                <div class=\"emission-item\" data-bo-t" \
"ype=\"edition\" data-bo-nid=\"WB5214082-F24-FR-20180105\">\n" \
"                <div class=\"media video\">\n" \
"                    <img style=\"width:324px; height:182px;\" src=\"ht" \
"tp://scd.france24.com/fr/files_fr/imagecache/hermes_infographie_carous" \
"sel_home/edition/1801.png\" alt=\"\"/><span/>\n" \
"                </div>\n" \
"                <div class=\"copy\">\n" \
"                    <p>MODE</p>\n" \
"                    <h4>La mode en 2017&#xA0;: f&#xE9;minisme, busines" \
"s et tabous &#xE0; briser</h4>\n" \
"                </div>\n" \
"                <p class=\"default-read-more\"><a rel=\"nofollow\" cla" \
"ss=\"modeless\" href=\"/fr/20180105-mode-dior-lvmh-harcelement-maigreu" \
"r-hyeres-barcelone-beyrouth-madrid-fashion-week\">En savoir plus</a></" \
"p>\n" \
"            </div>\n" \
"                                <div class=\"emission-item\" data-bo-t" \
"ype=\"edition\" data-bo-nid=\"WB5214076-F24-FR-20180105\">\n" \
"                <div class=\"media video\">\n" \
"                    <img style=\"width:324px; height:182px;\" src=\"ht" \
"tp://scd.france24.com/fr/files_fr/imagecache/hermes_infographie_carous" \
"sel_home/edition/dls_rvpi_wsj.png.jpg\" alt=\"\"/><span/>\n" \
"                </div>\n" \
"                <div class=\"copy\">\n" \
"                    <p>REVUE DE PRESSE</p>\n" \
"                    <h4>Trump pour \"une expansion massive des forages" \
" p&#xE9;troliers offshore\"</h4>\n" \
"                </div>\n" \
"                <p class=\"default-read-more\"><a rel=\"nofollow\" cla" \
"ss=\"modeless\" href=\"/fr/20180105-offshore-etats-unis-trump-exploita" \
"tion-hydrocarbures-avocate-ukrainienne-assassinat\">En savoir plus</a>" \
"</p>\n" \
"            </div>\n" \
"                                <div class=\"emission-item\" data-bo-t" \
"ype=\"edition\" data-bo-nid=\"WB5214068-F24-FR-20180105\">\n" \
"                <div class=\"media video\">\n" \
"                    <img style=\"width:324px; height:182px;\" src=\"ht" \
"tp://scd.france24.com/fr/files_fr/imagecache/hermes_infographie_carous" \
"sel_home/edition/dls_rvp_une_huma.png_1.jpg\" alt=\"\"/><span/>\n" \
"                </div>\n" \
"                <div class=\"copy\">\n" \
"                    <p>REVUE DE PRESSE</p>\n" \
"                    <h4>Erdogan en visite &#xE0; Paris&#xA0;: \"Le d&#" \
"xE9;jeuner qui fait grincer\"</h4>\n" \
"                </div>\n" \
"                <p class=\"default-read-more\"><a rel=\"nofollow\" cla" \
"ss=\"modeless\" href=\"/fr/20180105-erdogan-visite-paris-macron-droits" \
"-homme-purges-zad-carte-loeb-dakar-perou\">En savoir plus</a></p>\n" \
"            </div>\n" \
"                                <div class=\"emission-item\" data-bo-t" \
"ype=\"edition\" data-bo-nid=\"WB5214050-F24-FR-20180105\">\n" \
"                <div class=\"media video\">\n" \
"                    <img style=\"width:324px; height:182px;\" src=\"ht" \
"tp://scd.france24.com/fr/files_fr/imagecache/hermes_infographie_carous" \
"sel_home/edition/photo_eco_encadre_turquie.jpg\" alt=\"\"/><span/>\n" \
"                </div>\n" \
"                <div class=\"copy\">\n" \
"                    <p>LE JOURNAL DE L'&#xC9;CO</p>\n" \
"                    <h4>Erdogan &#xE0; Paris, une visite aux accents &" \
"#xE9;conomiques</h4>\n" \
"                </div>\n" \
"                <p class=\"default-read-more\"><a rel=\"nofollow\" cla" \
"ss=\"modeless\" href=\"/fr/20180105-turquie-erdogan-france-cuba-mogher" \
"ini-moneygram-or-air-france-spotify-galette\">En savoir plus</a></p>\n" \
"            </div>\n" \
"                                <div class=\"emission-item\" data-bo-t" \
"ype=\"edition\" data-bo-nid=\"WB5213972-F24-FR-20180104\">\n" \
"                <div class=\"media video\">\n" \
"                    <img style=\"width:324px; height:182px;\" src=\"ht" \
"tp://scd.france24.com/fr/files_fr/imagecache/hermes_infographie_carous" \
"sel_home/edition/salah-mohamed-ballon-dor-africain_ok.jpeg\" alt=\"\"/" \
"><span/>\n" \
"                </div>\n" \
"                <div class=\"copy\">\n" \
"                    <p>LE JOURNAL DE L&#x2019;AFRIQUE</p>\n" \
"                    <h4>L'&#xC9;gyptien Mohamed Salah sacr&#xE9; Joueu" \
"r africain de l'ann&#xE9;e</h4>\n" \
"                </div>\n" \
"                <p class=\"default-read-more\"><a rel=\"nofollow\" cla" \
"ss=\"modeless\" href=\"/fr/20180104-mohamed-salah-joueur-africain-anne" \
"e-rdc-eglise-catholique-togo-gnassingbe\">En savoir plus</a></p>\n" \
"            </div>\n" \
"            </div>\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"                                        \n" \
"    <div class=\"ib-adv tms-block\" data-pos=\"2\" data-type=\"pave\" " \
"data-location=\"sidebar\" data-expand=\"true\" data-loaded=\"false\">\n" \
"    </div>\n" \
"\n" \
"\n" \
"\n" \
"        <div class=\"intro-program\">\n" \
"        <div class=\"ip-item\">\n" \
"                        <div class=\"bd\">\n" \
"                                                            \n" \
"    <div class=\"tms-block\" data-pos=\"1\" data-type=\"partner_block\"" \
" data-location=\"sidebar\" data-expand=\"true\" data-loaded=\"false\">" \
"\n" \
"    </div>\n" \
"\n" \
"\n" \
"            </div>\n" \
"        </div>\n" \
"\n" \
"    </div>\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"\n" \
"    \n" \
"        \n" \
"             </aside></div>\n" \
"                                                                      " \
"                                      </div>\n" \
"                    </div>\n" \
"                </div>\n" \
"            </div>\n" \
"            <footer><div class=\"inner\">\n" \
"    <img class=\"f-logo\" src=\"/bundles/aefhermesf24/img/france-24-lo" \
"go.png?version=20171213121500\" alt=\"\"/><div class=\"f-link-list fl-" \
"l-l-1 fl-l-l-l-1\">\n" \
"                <p>Actualit&#xE9;</p>\n" \
"                <ul><li><a class=\"modeless\" href=\"/fr/\" title=\"In" \
"fos, news &amp; actualit&#xE9;s - L'information internationale en dire" \
"ct\">&#xC0; la une</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/france/\" title=\"FRANCE : News et " \
"actualit&#xE9; en continu\">France</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/afrique/\" title=\"Politique &amp; " \
"&#xE9;conomie en AFRIQUE, infos &amp; news au Maghreb\">Afrique</a></l" \
"i>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/moyen-orient/\" title=\"Information" \
"s et news au MOYEN-ORIENT - Toute l'actualit&#xE9; sur France 24\">Moy" \
"en-Orient</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/ameriques/\" title=\"Am&#xE9;riques" \
" : information en direct, news et actu en continu - France 24\">Am&#xE" \
"9;riques</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/europe/\" title=\"News, actualit&#x" \
"E9; politique &amp; &#xE9;conomique en Europe - France 24\">Europe</a>" \
"</li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/asie-pacifique/\" title=\"Asie et P" \
"acifique : actualit&#xE9; internationale en continu - France 24\">Asie" \
"-Pacifique</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/eco-tech/\" title=\"&#xC9;CONOMIE &" \
"amp; TECHNOLOGIE : toute l'actu &#xE9;co &amp; tech\">&#xC9;co/Tech</a" \
"></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/sports/\" title=\"SPORT : toutes le" \
"s news sportives et les r&#xE9;sultats\">Sport</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/culture/\" title=\"CULTURE &amp; ar" \
"tistes : l'actualit&#xE9; culturelle &amp; artistique\">Culture</a></l" \
"i>\n" \
"                                                            </ul></div" \
">\n" \
"            \n" \
"                        <div class=\"f-link-list fl-l-l-2\">\n" \
"                <p>la cha&#xEE;ne</p>\n" \
"                <ul><li><a href=\"/fr/tv-en-direct-chaine-live\" class" \
"=\"modeless video\" title=\"Regarder France 24 en direct\">La cha&#xEE" \
";ne en direct</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"/fr/actualites-sous-titrees\" class=\"modeless video\" tit" \
"le=\"Suivez les derni&#xE8;res informations sous-titr&#xE9;es et la m&" \
"#xE9;t&#xE9;o\">Accessibilit&#xE9;</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"/fr/emissions/\" class=\"modeless\" title=\"Programmes TV," \
" Emissions et news en VOD\">&#xC9;missions</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"/fr/reportages/\" class=\"modeless\" title=\"Tous les repo" \
"rtages des grands reporters de France 24 aux 4 coins du monde\">Report" \
"ages</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"/fr/emissions/revue-presse/\" class=\"modeless\" title=\"R" \
"evue de presse\">Revue de presse</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"/fr/emissions/\" class=\"modeless\" title=\"Podcasts\">Pod" \
"casts</a></li>\n" \
"                                                            </ul></div" \
">\n" \
"                    <div class=\"f-link-list fl-l-l-3\">\n" \
"                <p>Aller plus loin</p>\n" \
"                <ul><li><a href=\"http://observers.france24.com/fr/\" " \
"title=\"Les Observateurs\" target=\"_blank\">Les Observateurs</a></li>" \
"\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"http://mashable.france24.com/\" title=\"Mashable avec Fran" \
"ce 24\" target=\"_blank\">Mashable FR</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/webdocumentaires/\" title=\"Infogra" \
"phies et Webdocumentaires\">Webdocumentaires</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a class=\"modeless\" href=\"/fr/dossiers/\" title=\"Tous les Dossie" \
"rs sp&#xE9;ciaux de la r&#xE9;daction France 24\">Dossiers</a></li>\n" \
"                                                            </ul></div" \
">\n" \
"                    <div class=\"f-link-list fl-l-l-4\">\n" \
"                <p>Services 24/7</p>\n" \
"                <ul><li><a href=\"https://emailing.france24.com/fr/sub" \
"scribe\" title=\"Newsletters\" target=\"_blank\">Newsletters</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"https://emailing.france24.com/fr/subscribe\" title=\"Espac" \
"e personnel\" target=\"_blank\">Espace personnel</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"/fr/mobile\" class=\"modeless\" title=\"Applications Mobil" \
"es et Tablettes\">Mobiles / Tablettes</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"/fr/tv-connectee\" class=\"modeless\" title=\"France 24 su" \
"r la TV connect&#xE9;e\">TV connect&#xE9;es</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"/fr/rss\" class=\"modeless\" title=\"Flux RSS\">Flux RSS</" \
"a></li>\n" \
"                                                            </ul></div" \
">\n" \
"            \n" \
"    <span class=\"f-line-1\"/>\n" \
"    <span class=\"f-line-2\"/>\n" \
"            <div class=\"f-social-link\">\n" \
"                                                                      " \
"                          \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                <a href=\"https://emailing.france24.com/fr/subscribe\"" \
" title=\"Rejoignez la communaut&#xE9; France 24\" target=\"_blank\">Re" \
"joignez la communaut&#xE9;</a>\n" \
"                                                                      " \
"                                  \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                <a href=\"/fr/medias-sociaux\" class=\"modeless\" titl" \
"e=\"Retrouvez France 24 sur les m&#xE9;dias sociaux\">France 24 sur le" \
"s m&#xE9;dias sociaux</a>\n" \
"                                                                      " \
"      <ul><li><a href=\"http://f24.my/rhako6\" class=\"fb\" title=\"Fa" \
"cebook\" target=\"_blank\">Facebook</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"http://f24.my/XLkdot\" class=\"tw\" title=\"Twitter\" targ" \
"et=\"_blank\">Twitter</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"http://f24.my/tASiE4\" class=\"go\" title=\"Google +\" tar" \
"get=\"_blank\">Google +</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"http://f24.my/cHF8Wc\" class=\"dm\" title=\"Dailymotion\" " \
"target=\"_blank\">Dailymotion</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"http://f24.my/bGRWve\" class=\"yt\" title=\"Youtube\" targ" \
"et=\"_blank\">Youtube</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"http://f24.my/oTjdan\" class=\"fs\" title=\"Foursquare\" t" \
"arget=\"_blank\">Foursquare</a></li>\n" \
"                                                                      " \
"                                                      \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                    <l" \
"i><a href=\"http://f24.my/nsM8q8\" class=\"sc\" title=\"Soundcloud\" t" \
"arget=\"_blank\">Soundcloud</a></li>\n" \
"                                                            </ul></div" \
">\n" \
"                                                    \n" \
"    <div class=\"f-adv tms-block\" data-pos=\"1\" data-type=\"pave\" d" \
"ata-location=\"footer\" data-expand=\"false\" data-loaded=\"false\">\n" \
"    </div>\n" \
"\n" \
"\n" \
"                                                                      " \
"                                                                      " \
"                                                            <div class" \
"=\"f-map\">\n" \
"            <a href=\"/fr/comment-recevoir-la-chaine\" class=\"modeles" \
"s\" title=\"Recevoir France 24\">Recevoir France 24</a>\n" \
"        </div>\n" \
"                <nav class=\"f-nav\"><ul><li><a href=\"/fr/entreprise\"" \
" class=\"modeless\" title=\"L'Entreprise France 24\">&#xC0; propos de " \
"France 24</a></li>\n" \
"                                                                      " \
"                              \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                <li><a href=\"/fr/tag/" \
"communique-presse/\" class=\"modeless\" title=\"Communiqu&#xE9;s de Pr" \
"esse\">Presse</a></li>\n" \
"                                                                      " \
"                              \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                            <li><a href=\"http://static.france24.com/i" \
"nfographies/presse/FRANCE24_PressKit_1214_FR.pdf\" class=\"\" title=\"" \
"\" target=\"_blank\">Dossier de presse</a></li>\n" \
"                                                                      " \
"                              \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                <li><a href=\"/fr/cont" \
"actez-nous?section=publicite\" class=\"modeless\" title=\"Opportunit&#" \
"xE9;s publicitaires et partenariats\">R&#xE9;gie publicitaire</a></li>" \
"\n" \
"                                                                      " \
"                              \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                <li><a href=\"/fr/cont" \
"actez-nous\" class=\"modeless\" title=\"Contact\">Contact</a></li>\n" \
"                                                                      " \
"                              \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                <li><a href=\"https://" \
"careerpage.multiposting.fr/career/france-medias-monde/\" class=\"model" \
"ess\" title=\"Nous rejoindre\">Nous rejoindre</a></li>\n" \
"                                                                      " \
"                              \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                <li><a href=\"/fr/plan" \
"-du-site\" class=\"modeless\" title=\"Plan du site\">Plan du site</a><" \
"/li>\n" \
"                                                                      " \
"                              \n" \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                                      " \
"                                                <li><a href=\"/fr/ment" \
"ions-legales\" class=\"modeless\" title=\"Mentions l&#xE9;gales\">Ment" \
"ions l&#xE9;gales</a></li>\n" \
"                                                    </ul></nav><div cl" \
"ass=\"f-partner\">\n" \
"        <a href=\"http://www.rfi.fr/\" target=\"_blank\"><img src=\"/b" \
"undles/aefhermesf24/img/rfi-logo.png?version=20171213121500\" alt=\"\"" \
"/></a>\n" \
"        <a href=\"/fr/\" target=\"_blank\"><img src=\"/bundles/aefherm" \
"esf24/img/france24-logo.png?version=20171213121500\" alt=\"\"/></a>\n" \
"        <a href=\"http://www.mc-doualiya.com/\" target=\"_blank\"><img" \
" src=\"/bundles/aefhermesf24/img/mcd-logo.png?version=20171213121500\"" \
" alt=\"\"/></a>\n" \
"        <a href=\"http://www.francemediasmonde.com\" target=\"_blank\"" \
"><img src=\"/bundles/aefhermesf24/img/fmm-logo.png?version=20171213121" \
"500\" alt=\"\"/></a>\n" \
"    </div>\n" \
"    <p class=\"f-copy\">\n" \
"        &#xA9; 2018 Copyright France 24 &#x2013; Tous droits r&#xE9;se" \
"rv&#xE9;s<br/>\n" \
"        France 24 n'est pas responsable des contenus provenant de site" \
"s Internet externes<br/><a href=\"http://www.acpm.fr/Marque/marque-fra" \
"nce-24\" target=\"_blank\" rel=\"nofollow\" class=\"ojd\">Fr&#xE9;quen" \
"tation certifi&#xE9;e par l'ACPM/OJD</a>\n" \
"            </p>\n" \
"</div>\n" \
"\n" \
"                            </footer><!-- mobile placeholder F24x4 -->" \
"<style type=\"text/css\"><![CDATA[\n" \
"/* Masquage JR */\n" \
".user-janrain, #janrain {\n" \
"display: none;\n" \
"}\n" \
".g-list .copy {line-height: 20px; padding: 2px 6px !important;}\n" \
".orientation-center{width: 100% !important;}\n" \
".citation-material.orientation-center{width: auto !important;}\n" \
".default-header-2{width: auto !important;}\n" \
"#SCRBBL-TOP {display:none !important;}\n" \
"#nav-main-special-event {\n" \
"margin-bottom: 10px !important;\n" \
"height: 30px !important;\n" \
"}\n" \
".main-nav .item-im {\n" \
"height: 21px;\n" \
"text-indent: -9999px !important;\n" \
"background: transparent url(//static.france24.com/infomigrants/menu/lo" \
"go_fren_v2@1x.png) center center no-repeat;\n" \
"}\n" \
".main-nav .item-mash {\n" \
"height: 21px;\n" \
"text-indent: -9999px !important;\n" \
"background: transparent url(//static.france24.com/mashable/menu/logo@1" \
"x.png) center center no-repeat;\n" \
"}\n" \
".site-pusher nav li .logo-im {\n" \
"display: block;\n" \
"padding: 10px;\n" \
"height: 21px;\n" \
"overflow: hidden;\n" \
"text-indent: -9999em;\n" \
"background-image: url(//static.france24.com/infomigrants/menu/logo_fre" \
"n_v2@1x.png);\n" \
"background-position: left 10px center;\n" \
"background-repeat: no-repeat;\n" \
"}\n" \
".site-pusher nav li .logo-mashfr {\n" \
"display: block;\n" \
"margin: 10px;\n" \
"height: 21px;\n" \
"overflow: hidden;\n" \
"text-indent: -9999em;\n" \
"background-image: url(//static.france24.com/mashable/menu/logo@1x.png)" \
";\n" \
"background-position: left center;\n" \
"background-repeat: no-repeat;\n" \
"}\n" \
".site-pusher nav li a.m-cgu {\n" \
"font-size: 80%;\n" \
"}\n" \
".site-pusher nav ul li:nth-last-child(2) a, .site-pusher nav ul li:nth" \
"-last-child(1) a {\n" \
"border-bottom: none;\n" \
"}\n" \
".site-pusher nav ul li:nth-last-child(2) {\n" \
"border-bottom: 1px solid #ccc;\n" \
"border-top: 1px solid #ccc;\n" \
"}\n" \
"/* menu d?roulant */\n" \
".sc-info .bd:hover {\n" \
"max-height: 285px !important;\n" \
"}\n" \
"/* fixed for bs player fallback */\n" \
".alt-player.bsplayer-container {\n" \
"padding-bottom:10px;\n" \
"}\n" \
"]]></style><script type=\"text/javascript\"><![CDATA[\n" \
"function handleAjaxSuccess() {\n" \
"if (typeof($) !== 'function') {\n" \
"return;\n" \
"}\n" \
"$(document).ajaxSuccess(function(event, xhr, settings) {\n" \
"if (settings.url.indexOf('player/tofollow') > 1) {\n" \
"setTimeout(function () {\n" \
"$('[data-player-playlist^=\"replay\"]')\n" \
".each(function() {\n" \
"var $data = $(this).text();\n" \
"var $dataJson = JSON.parse($data);\n" \
"$dataJson = $.extend(true, $dataJson, {\n" \
"'medias': {\n" \
"'media': {\n" \
"'rolls': {\n" \
"'urlpre': 'http://ad2play.ftv-publicite.fr/preroll.vast?v=2&sitepage=w" \
"ww.france24.fr/journaletchroniques',\n" \
"'urlpost': ''\n" \
"}\n" \
"}\n" \
"}\n" \
"});\n" \
"$(this).text(JSON.stringify($dataJson));\n" \
"});\n" \
"}, 200);\n" \
"}\n" \
"});\n" \
"}\n" \
"window.CEM = function() {\n" \
"//handleAjaxSuccess();\n" \
"};\n" \
"// AJOUT SUPPRESSION SURTITRE VIDEO\n" \
"function defer(method) {\n" \
"if (window.jQuery)\n" \
"method();\n" \
"else\n" \
"setTimeout(function() { defer(method) }, 200);\n" \
"}\n" \
"function cleanVideoTitle() {\n" \
"$(\"div.tab div.copy p.place:contains('Grab')\").css('display','none')" \
";\n" \
"$(\"div.tab div.copy p.place:contains('PKG')\").css('display','none');" \
"\n" \
"$(\"div.tab div.copy p.place:contains('INTRO')\").css('display','none'" \
");\n" \
"$(\"div.tab div.copy p.place:contains('GREB')\").css('display','none')" \
";\n" \
"$(\"div.tab div.copy p.place:contains('GRAB')\").css('display','none')" \
";\n" \
"}\n" \
"defer(cleanVideoTitle);\n" \
"defer(function(){\n" \
"$(document).ajaxSuccess(function() {\n" \
"cleanVideoTitle();\n" \
"});\n" \
"});\n" \
"// FIN SUPPRESSION SURTITRE VIDEO\n" \
"]]></script><div class=\"short-cuts-outer\">\n" \
"                                        <div class=\"short-cuts\">\n" \
"                \n" \
"                                                            \n" \
"            <div class=\"sc-search\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <p class=\"hd\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <a href=\"#\">\n" \
"            search\n" \
"                    </a>\n" \
"    \n" \
"                                    </p>\n" \
"    \n" \
"                                        \n" \
"                                                            \n" \
"            <div class=\"bd\">\n" \
"            \n" \
"                                                    \n" \
"                            \n" \
"            <form name=\"Search\" method=\"get\" action=\"/fr/recherch" \
"e/\" id=\"sinequa-search-form\"><div><label for=\"Search_term\" class=" \
"\"required\">Terme</label><input type=\"text\" id=\"Search_term\" name" \
"=\"Search[term]\" required=\"required\" placeholder=\"Recherche&#x2026" \
";\"/></div><input type=\"hidden\" id=\"Search_page\" name=\"Search[pag" \
"e]\" value=\"1\"/><div><button type=\"submit\">Lancer la recherche</bu" \
"tton></div><div><label class=\"required\">Filters</label><div id=\"Sea" \
"rch_filters\"/></div></form>\n" \
"    \n" \
"                                    </div>\n" \
"    \n" \
"                                    </div>\n" \
"    \n" \
"                \n" \
"                                                            \n" \
"            <div class=\"sc-mail\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <p class=\"hd\">\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"https://emailing.france24.com/fr/subscribe\" tar" \
"get=\"_blank\">\n" \
"            e-mail\n" \
"                    </a>\n" \
"    \n" \
"                                    </p>\n" \
"    \n" \
"                                    </div>\n" \
"    \n" \
"                \n" \
"                                                            \n" \
"            <div class=\"sc-info\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <p class=\"hd\">\n" \
"            France M&#xE9;dias Monde\n" \
"                    </p>\n" \
"    \n" \
"                                        \n" \
"                                                            \n" \
"            <div class=\"bd\">\n" \
"            \n" \
"                                                    \n" \
"                            \n" \
"            <ul><li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://observers.france24.com/fr\" target=\"_bla" \
"nk\">\n" \
"            Les Observateurs\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://mashable.france24.com\" target=\"_blank\"" \
">\n" \
"            Mashable FR\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://www.rfi.fr/\" target=\"_blank\">\n" \
"            RFI \n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://musique.rfi.fr/\" target=\"_blank\">\n" \
"            RFI Musique\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"https://savoirs.rfi.fr/\" target=\"_blank\">\n" \
"            RFI Savoirs\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://atelier.rfi.fr/\" target=\"_blank\">\n" \
"            Atelier des m&#xE9;dias\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://mondoblog.org/\" target=\"_blank\">\n" \
"            Mondoblog\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://www.mc-doualiya.com/\" target=\"_blank\">" \
"\n" \
"            Monte Carlo Doualiya\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://academie.france24-mcd-rfi.com/fr/\" targe" \
"t=\"_blank\">\n" \
"            Acad&#xE9;mie\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://www.cfi.fr/\" target=\"_blank\">\n" \
"            CFI\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://www.francemediasmonde.com/\" target=\"_bl" \
"ank\">\n" \
"            France M&#xE9;dias Monde\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                        \n" \
"                            \n" \
"            <li>\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"http://www.rfi-instrumental.com/fr\" target=\"_b" \
"lank\">\n" \
"            RFI Instrumental\n" \
"                    </a>\n" \
"    \n" \
"                                    </li>\n" \
"    \n" \
"                                    </ul></div>\n" \
"    \n" \
"                                    </div>\n" \
"    \n" \
"                \n" \
"                                                            \n" \
"            <div class=\"sc-rec\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <p class=\"hd\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <a href=\"/fr/comment-recevoir-la-chaine\">\n" \
"            Recevoir France 24\n" \
"                    </a>\n" \
"    \n" \
"                                    </p>\n" \
"    \n" \
"                                    </div>\n" \
"    \n" \
"                \n" \
"                                                            \n" \
"            <div class=\"sc-voy\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <p class=\"hd\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <a href=\"/fr/voyage\">\n" \
"            Voyage\n" \
"                    </a>\n" \
"    \n" \
"                                    </p>\n" \
"    \n" \
"                                    </div>\n" \
"    \n" \
"                \n" \
"                                                            \n" \
"            <div class=\"sc-lang\">\n" \
"            \n" \
"                                                    \n" \
"                                                            \n" \
"            <p class=\"hd\">\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"/fr/\" class=\"active\">\n" \
"            Fran&#xE7;ais\n" \
"                    </a>\n" \
"    \n" \
"                                        \n" \
"                                                                      " \
"          \n" \
"            <a href=\"/en/\" class=\"\">\n" \
"            English\n" \
"                    </a>\n" \
"    \n" \
"                                        \n" \
"                                                                      " \
"          \n" \
"            <a href=\"/es/\" class=\"\">\n" \
"            Espa&#xF1;ol\n" \
"                    </a>\n" \
"    \n" \
"                                        \n" \
"                                                                      " \
"          \n" \
"            <a href=\"/ar/\" class=\"\">\n" \
"            &#x639;&#x631;&#x628;&#x64A;\n" \
"                    </a>\n" \
"    \n" \
"                                    </p>\n" \
"    \n" \
"                                        \n" \
"                                                            \n" \
"            <p class=\"hd\">\n" \
"            \n" \
"                                                    \n" \
"                                                                      " \
"          \n" \
"            <a href=\"/fr/actualites-sous-titrees\" class=\"accessibil" \
"ity\">\n" \
"            Accessibilit&#xE9;\n" \
"                    </a>\n" \
"    \n" \
"                                    </p>\n" \
"    \n" \
"                                    </div>\n" \
"    \n" \
"        <div class=\"user-janrain sc-info\">\n" \
"    <div id=\"user-disconnected\">\n" \
"        <a href=\"#\" data-user=\"signin\" class=\"hd active\">Mon com" \
"pte</a>\n" \
"        <div class=\"bd\" data-user=\"disconnected\">\n" \
"            <ul><li>\n" \
"                    <a data-user=\"signin\" href=\"#\" target=\"_self\"" \
" class=\"\">Connexion</a>\n" \
"                </li>\n" \
"                <li>\n" \
"                    <a href=\"/fr/rejoindre-la-communaute\" target=\"_" \
"self\" class=\"\">Pr&#xE9;sentation</a>\n" \
"                </li>\n" \
"                <li>\n" \
"                    <a href=\"/fr/rejoindre-communaute/faq\" target=\"" \
"_self\" class=\"\">Aide</a>\n" \
"                </li>\n" \
"            </ul></div>\n" \
"    </div>\n" \
"    <div id=\"user-connected\">\n" \
"        <p class=\"hd\">\n" \
"            <span class=\"user-avatar\"/>\n" \
"            <span class=\"user-name\" id=\"displayName\"/>\n" \
"        </p>\n" \
"        <div class=\"bd\" data-user=\"connected\">\n" \
"            <ul><li>\n" \
"                    <a href=\"#\" data-user=\"editProfile\" class=\"\"" \
">Mon Profil</a>\n" \
"                </li>\n" \
"                <li>\n" \
"                    <a href=\"/fr/rejoindre-la-communaute\" target=\"_" \
"self\" class=\"\">Pr&#xE9;sentation</a>\n" \
"                </li>\n" \
"                <li>\n" \
"                    <a href=\"/fr/rejoindre-communaute/faq\" target=\"" \
"_self\" class=\"\">Aide</a>\n" \
"                </li>\n" \
"                <li>\n" \
"                    <a href=\"#\" data-user=\"signout\" class=\"\">Me " \
"d&#xE9;connecter</a>\n" \
"                </li>\n" \
"            </ul></div>\n" \
"    </div>\n" \
"</div>\n" \
"\n" \
"<div class=\"parameters-link\">\n" \
"    <a class=\"tos\" href=\"/fr/mentions-legales\" target=\"_self\"/>\n" \
"</div>\n" \
"</div>\n" \
"\n" \
"                            </div>\n" \
"                            <div id=\"janrain\">\n" \
"                    \n" \
"<div style=\"display:none\" id=\"signIn\"><div class=\"capture_header\"" \
"><h2>Cr&#xE9;er un compte / Se connecter</h2></div><div class=\"captur" \
"e_signin\"><h2>Avec le compte existant de...</h2>{* loginWidget *}<br/" \
"></div><div class=\"capture_backgroundColor\"><div class=\"capture_sig" \
"nin\"><h2>Avec un compte habituel</h2>{* #signInForm *} {* signInEmail" \
"Address *} {* currentPassword *}<div class=\"capture_form_item\"><a hr" \
"ef=\"#\" data-capturescreen=\"forgotPassword\">Mot de passe oubli&#xE9" \
"; ?</a></div><div class=\"capture_rightText\"><button class=\"capture_" \
"secondary capture_btn capture_primary\" type=\"submit\"><span class=\"" \
"janrain-icon-16 janrain-icon-key\"/> Se connecter</button> <a href=\"#" \
"\" id=\"capture_signIn_createAccountButton\" data-capturescreen=\"trad" \
"itionalRegistration\" class=\"capture_secondary capture_createAccountB" \
"utton capture_btn capture_primary\">Cr&#xE9;er un compte</a></div>{* /" \
"signInForm *}</div></div></div><div style=\"display:none\" id=\"return" \
"Social\"><div class=\"capture_header\"><h2>Sign In</h2></div><div clas" \
"s=\"capture_signin\"><h2>Bienvenue ! {* welcomeName *}</h2>{* loginWid" \
"get *}<div class=\"capture_centerText switchLink\"><a href=\"#\" data-" \
"cancelcapturereturnexperience=\"true\">Use another account</a></div></" \
"div></div><div style=\"display:none\" id=\"returnTraditional\"><div cl" \
"ass=\"capture_header\"><h2>Se connecter</h2></div><h2 class=\"capture_" \
"centerText\"><span>Bienvenue !</span></h2><div class=\"capture_backgro" \
"undColor\">{* #signInForm *} {* signInEmailAddress *} {* currentPasswo" \
"rd *}<div class=\"capture_form_item capture_rightText\"><button class=" \
"\"capture_secondary capture_btn capture_primary\" type=\"submit\"><spa" \
"n class=\"janrain-icon-16 janrain-icon-key\"/> Se connecter</button></" \
"div>{* /signInForm *}<div class=\"capture_centerText switchLink\"><a h" \
"ref=\"#\" data-cancelcapturereturnexperience=\"true\">Utiliser un autr" \
"e compte</a></div></div></div><div style=\"display:none\" id=\"account" \
"Deactivated\"><div class=\"capture_header\"><h2>Compte d&#xE9;sactiv&#" \
"xE9;</h2></div><div class=\"content_wrapper\"><p>Votre compte a &#xE9;" \
"t&#xE9; d&#xE9;sactiv&#xE9;</p></div></div><div style=\"display:none\"" \
" id=\"emailNotVerified\"><div class=\"capture_header\"><h1>Adresse ema" \
"il non v&#xE9;rifi&#xE9;e</h1></div><p>Vous devez v&#xE9;rifier votre " \
"adresse email pour finaliser votre inscription. Consultez votre boite " \
"mail pour valider votre adresse en cliquant sur le lien figurant dans " \
"le mail de confirmation ou entrez &#xE0; nouveau votre adresse email p" \
"our recevoir une nouvelle fois le mail de confirmation.</p>{* #resendV" \
"erificationForm *} {* signInEmailAddress *}<div class=\"capture_footer" \
"\"><input value=\"Envoyer\" type=\"submit\" class=\"capture_btn captur" \
"e_primary\"/></div>{* /resendVerificationForm *}</div>\n" \
"<div style=\"display:none\" id=\"socialRegistration\"><div class=\"cap" \
"ture_header\"><h2>C'est presque fini !</h2></div><h2>Merci de confirme" \
"r les informations ci-dessous avant de vous connecter</h2>{* #socialRe" \
"gistrationForm *} {* firstName *} {* lastName *} {* emailAddress *} {*" \
" displayName *} {* phone *} {* addressCity *} {* addressCountry *} En " \
"cliquant sur \"Cr&#xE9;er un compte\", vous confirmez que vous accepte" \
"z nos &#xA0; <a class=\"termsOfService\" href=\"#\">conditions g&#xE9;" \
"n&#xE9;rales</a>&#xA0; et que vous avez lu et approuv&#xE9; la&#xA0; <" \
"a class=\"privacyPolicy\" href=\"#\">politique de protection de donn&#" \
"xE9;es personnelles</a>.<div class=\"capture_footer\"><div class=\"cap" \
"ture_left\">{* backButton *}</div><div class=\"capture_right\"><input " \
"value=\"Cr&#xE9;er un compte\" type=\"submit\" class=\"capture_btn cap" \
"ture_primary\"/></div></div>{* /socialRegistrationForm *}</div><div st" \
"yle=\"display:none\" id=\"traditionalRegistration\"><div class=\"captu" \
"re_header\"><h2>C'est presque fini !</h2></div><p>Merci de confirmer l" \
"es informations ci-dessous avant de vous connecter <a id=\"capture_tra" \
"ditionalRegistration_navSignIn\" href=\"#\" data-capturescreen=\"signI" \
"n\">Se connecter</a></p>{* #registrationForm *} {* firstName *} {* las" \
"tName *} {* emailAddress *} {* displayName *} {* phone *} {* addressCi" \
"ty *} {* addressCountry *} {* newPassword *} {* newPasswordConfirm *} " \
"En cliquant sur \"Cr&#xE9;er un compte\", vous confirmez que vous acce" \
"ptez nos &#xA0; <a class=\"termsOfService\" href=\"#\">conditions g&#x" \
"E9;n&#xE9;rales</a>&#xA0; et que vous avez lu et approuv&#xE9; la&#xA0" \
"; <a class=\"privacyPolicy\" href=\"#\">politique de protection de don" \
"n&#xE9;es personnelles</a>.<div class=\"capture_footer\"><div class=\"" \
"capture_left\">{* backButton *}</div><div class=\"capture_right\"><inp" \
"ut value=\"Cr&#xE9;er un compte\" type=\"submit\" class=\"capture_btn " \
"capture_primary\"/></div></div>{* /registrationForm *}</div><div style" \
"=\"display:none\" id=\"emailVerificationNotification\"><div class=\"ca" \
"pture_header\"><h2>Merci de votre inscription</h2></div><p>Nous vous a" \
"vons envoy&#xE9; un email de confirmation &#xE0; l'adresse suivante&#x" \
"A0; {* emailAddressData *}.&#xA0; Merci de consulter votre bo&#xEE;te " \
"de r&#xE9;ception et de cliquer sur le lien pour activer votre compte." \
".</p><div class=\"capture_footer\"><a href=\"#\" onclick=\"janrain.cap" \
"ture.ui.modal.close()\" class=\"capture_btn capture_primary\">Fermer</" \
"a></div></div>\n" \
"<div style=\"display:none\" id=\"forgotPassword\"><div class=\"capture" \
"_header\"><h2>Cr&#xE9;er un nouveau mot de passe</h2></div><h2>Nous vo" \
"us enverrons un lien pour cr&#xE9;er un nouveau mot de passe</h2>{* #f" \
"orgotPasswordForm *} {* signInEmailAddress *}<div class=\"capture_foot" \
"er\"><div class=\"capture_left\">{* backButton *}</div><div class=\"ca" \
"pture_right\"><input value=\"Envoyer\" type=\"submit\" class=\"capture" \
"_btn capture_primary\"/></div></div>{* /forgotPasswordForm *}</div><di" \
"v style=\"display:none\" id=\"forgotPasswordSuccess\"><div class=\"cap" \
"ture_header\"><h2>Cr&#xE9;er un nouveau mot de passe</h2></div><p>Nous" \
" vous avons envoy&#xE9; un email avec les instructions pour cr&#xE9;er" \
" un nouveau mot de passe. Votre mot de passe actuel n'a pas &#xE9;t&#x" \
"E9; chang&#xE9;</p><div class=\"capture_footer\"><a href=\"#\" onclick" \
"=\"janrain.capture.ui.modal.close()\" class=\"capture_btn capture_prim" \
"ary\">Fermer</a></div></div>\n" \
"<div style=\"display:none\" id=\"mergeAccounts\">{* mergeAccounts {\"c" \
"ustom\": true} *}<div id=\"capture_mergeAccounts_mergeAccounts_mergeOp" \
"tionsContainer\" class=\"capture_mergeAccounts_mergeOptionsContainer\"" \
"><div class=\"capture_header\"><div class=\"capture_icon_col\">{| rend" \
"ered_current_photo |}</div><div class=\"capture_displayName_col\">{| c" \
"urrent_displayName |}<br/>{| current_emailAddress |}</div><span class=" \
"\"capture_mergeProvider janrain-provider-icon-24 janrain-provider-icon" \
"-{| current_provider_lowerCase |}\"/></div><div class=\"capture_dashed" \
"\"><div class=\"capture_mergeCol capture_centerText capture_left\"><p " \
"class=\"capture_bigText\">{| foundExistingAccountText |} <b>{| current" \
"_emailAddress |}</b>.</p><div class=\"capture_hover\"><div class=\"cap" \
"ture_popup_container\"><span class=\"capture_popup-arrow\"/>{| moreInf" \
"oHoverText |}<br/>{| existing_displayName |} - {| existing_provider |}" \
" : {| existing_siteName |} {| existing_createdDate |}</div>{| moreInfo" \
"Text |}</div></div><div class=\"capture_mergeCol capture_mergeExisting" \
"_col capture_right\"><div class=\"capture_shadow capture_backgroundCol" \
"or capture_border\">{| rendered_existing_provider_photo |}<div class=\"" \
"capture_displayName_col\">{| existing_displayName |}<br/>{| existing_p" \
"rovider_emailAddress |}</div><span class=\"capture_mergeProvider janra" \
"in-provider-icon-16 janrain-provider-icon-{| existing_provider_lowerCa" \
"se |}\"/><div class=\"capture_centerText capture_smallText\">Created {" \
"| existing_createdDate |} at {| existing_siteName |}</div></div></div>" \
"</div><div id=\"capture_mergeAccounts_form_collection_mergeAccounts_me" \
"rgeRadio\" class=\"capture_form_collection_merge_radioButtonCollection" \
" capture_form_collection capture_elementCollection capture_form_collec" \
"tion_mergeAccounts_mergeRadio\" data-capturefield=\"undefined\"><div i" \
"d=\"capture_mergeAccounts_form_item_mergeAccounts_mergeRadio_1_0\" cla" \
"ss=\"capture_form_item capture_form_item_mergeAccounts_mergeRadio capt" \
"ure_form_item_mergeAccounts_mergeRadio_1_0 capture_toggled\" data-capt" \
"urefield=\"undefined\"><label for=\"capture_mergeAccounts_mergeAccount" \
"s_mergeRadio_1_0\"><input id=\"capture_mergeAccounts_mergeAccounts_mer" \
"geRadio_1_0\" data-capturefield=\"undefined\" data-capturecollection=\"" \
"true\" value=\"1\" type=\"radio\" class=\"capture_mergeAccounts_mergeR" \
"adio_1_0 capture_input_radio\" checked=\"checked\" name=\"mergeAccount" \
"s_mergeRadio\"/> {| connectLegacyRadioText |}</label></div><div id=\"c" \
"apture_mergeAccounts_form_item_mergeAccounts_mergeRadio_2_1\" class=\"" \
"capture_form_item capture_form_item_mergeAccounts_mergeRadio capture_f" \
"orm_item_mergeAccounts_mergeRadio_2_1\" data-capturefield=\"undefined\"" \
"><label for=\"capture_mergeAccounts_mergeAccounts_mergeRadio_2_1\"><in" \
"put id=\"capture_mergeAccounts_mergeAccounts_mergeRadio_2_1\" data-cap" \
"turefield=\"undefined\" data-capturecollection=\"true\" value=\"2\" ty" \
"pe=\"radio\" class=\"capture_mergeAccounts_mergeRadio_2_1 capture_inpu" \
"t_radio\" name=\"mergeAccounts_mergeRadio\"/> {| createRadioText |} {|" \
" current_provider |}</label></div><div class=\"capture_tip\" style=\"d" \
"isplay:none\"/><div class=\"capture_tip_validating\" data-elementname=" \
"\"mergeAccounts_mergeRadio\">Validating</div><div class=\"capture_tip_" \
"error\" data-elementname=\"mergeAccounts_mergeRadio\"/></div><div clas" \
"s=\"capture_footer\">{| connect_button |} {| create_button |}</div></d" \
"iv></div><div style=\"display:none\" id=\"traditionalAuthenticateMerge" \
"\"><div class=\"capture_header\"><h2>Connectez-vous pour terminer la f" \
"usion des comptes</h2></div><div class=\"capture_signin\">{* #signInFo" \
"rm *} {* signInEmailAddress *} {* currentPassword *}<div class=\"captu" \
"re_footer\"><div class=\"capture_left\">{* backButton *}</div><div cla" \
"ss=\"capture_right\"><button class=\"capture_secondary capture_btn cap" \
"ture_primary\" type=\"submit\"><span class=\"janrain-icon-16 janrain-i" \
"con-key\"/> Se connecter</button></div></div>{* /signInForm *}</div></" \
"div>\n" \
"<div style=\"display:none\" id=\"verifyEmail\"><div class=\"capture_he" \
"ader\"><h2>Renvoyer l'email de v&#xE9;rification</h2></div><p>Merci d'" \
"avoir confirm&#xE9; votre adresse email</p>{* #resendVerificationForm " \
"*} {* signInEmailAddress *}<div class=\"capture_footer\"><input value=" \
"\"Submit\" type=\"submit\" class=\"capture_btn capture_primary\"/></di" \
"v>{* /resendVerificationForm *}</div><div style=\"display:none\" id=\"" \
"resendVerificationSuccess\"><div class=\"capture_header\"><h2>Un email" \
" de v&#xE9;rification vous a &#xE9;t&#xE9; envoy&#xE9;</h2></div><div " \
"class=\"hr\"/><p>V&#xE9;rifiez vos emails pour r&#xE9;cup&#xE9;rer le " \
"lien de changement de mot de passe</p><div class=\"capture_footer\"><a" \
" href=\"#\" data-user=\"signin\" class=\"capture_btn capture_primary\"" \
">Se connecter</a></div></div><div style=\"display:none\" id=\"verifyEm" \
"ailSuccess\"><div class=\"capture_header\"><h2>C'est fait !</h2></div>" \
"<p>Merci d'avoir confirm&#xE9; votre adresse email</p><div class=\"cap" \
"ture_footer\"><a href=\"#\" data-user=\"signin\" class=\"capture_btn c" \
"apture_primary\">Se connecter</a></div></div>\n" \
"<div style=\"display:none\" id=\"resetPassword\"><div class=\"capture_" \
"header\"><h2>Modifier le mot de passe</h2></div>{* #changePasswordForm" \
"NoAuth *} {* newPassword *} {* newPasswordConfirm *}<div class=\"captu" \
"re_footer\"><input value=\"Sauvegarder\" type=\"submit\" class=\"captu" \
"re_btn capture_primary\"/></div>{* /changePasswordFormNoAuth *}</div><" \
"div style=\"display:none\" id=\"resetPasswordSuccess\"><div class=\"ca" \
"pture_header\"><h2>Votre mot de passe a &#xE9;t&#xE9; chang&#xE9;</h2>" \
"</div><p>Votre mot de passe a &#xE9;t&#xE9; mis &#xE0; jour avec succ&" \
"#xE8;s.</p><div class=\"capture_footer\"><a href=\"#\" onclick=\"janra" \
"in.capture.ui.renderScreen('signIn')\" class=\"capture_btn capture_pri" \
"mary\">Se connecter</a></div></div><div style=\"display:none\" id=\"re" \
"setPasswordRequestCode\"><div class=\"capture_header\"><h2>Fermer</h2>" \
"</div><p>Nous n'avons pas reconnu le code de modification de mot de pa" \
"sse. Entrez &#xE0; nouveau votre adresse email pour recevoir un nouvea" \
"u code</p>{* #resetPasswordForm *} {* signInEmailAddress *}<div class=" \
"\"capture_footer\"><input value=\"Envoyer\" type=\"submit\" class=\"ca" \
"pture_btn capture_primary\"/></div>{* /resetPasswordForm *}</div><div " \
"style=\"display:none\" id=\"resetPasswordRequestCodeSuccess\"><div cla" \
"ss=\"capture_header\"><h2>Cr&#xE9;er un nouveau mot de passe</h2></div" \
"><p>Nous vous avons envoy&#xE9; un email avec les instructions pour cr" \
"&#xE9;er un nouveau mot de passe. Votre mot de passe actuel n'a pas &#" \
"xE9;t&#xE9; chang&#xE9;</p><div class=\"capture_footer\"><a href=\"#\"" \
" onclick=\"janrain.capture.ui.modal.close()\" class=\"capture_btn capt" \
"ure_primary\">Fermer</a></div></div>\n" \
"<div style=\"display:none\" id=\"editProfileModal\"><h2>Modifier votre" \
" compte</h2><div class=\"capture_grid_block\"><div class=\"capture_col" \
"_4\"><h3>Photo de profil</h3><div class=\"contentBoxWhiteShadow\">{* p" \
"hotoManager *}</div><h3>Comptes li&#xE9;s</h3><div class=\"contentBoxW" \
"hiteShadow\">{* linkedAccounts *} {* #linkAccountContainer *}<div clas" \
"s=\"capture_header\"><h2>Liez vos comptes</h2></div><h2>Vous pourrez d" \
"&#xE9;sormais vous connecter &#xE0; votre compte via ces identifiants<" \
"/h2><div class=\"capture_signin\">{* loginWidget *}</div>{* /linkAccou" \
"ntContainer *}</div><h3 class=\"janrain_traditional_account_only\">Mot" \
" de passe</h3><div class=\"janrain_traditional_account_only contentBox" \
"WhiteShadow\"><a href=\"#\" data-capturescreen=\"changePassword\">Modi" \
"fier le mot de passe</a></div><h3 class=\"janrain_traditional_account_" \
"only\">D&#xE9;sactiver le compte</h3><div class=\"capture_deactivate_s" \
"ection contentBoxWhiteShadow clearfix\"><a href=\"#\" data-capturescre" \
"en=\"confirmAccountDeactivation\">D&#xE9;sactiver le compte</a></div><" \
"/div><div class=\"capture_col_8\"><h3>Infos sur le compte</h3><div cla" \
"ss=\"contentBoxWhiteShadow\"><div class=\"capture_grid_block\"><div cl" \
"ass=\"capture_center_col capture_col_8\"><div class=\"capture_editCol\"" \
">{* #editProfileModalForm *}<fieldset class=\"contact-infos\"><legend>" \
"Vos informations personnelles</legend>{* firstName *} {* lastName *} {" \
"* gender *} {* birthdate *} {* displayName *} {* emailAddress *} {* re" \
"sendLink *} {* phone *} {* addressStreetAddress1 *} {* addressStreetAd" \
"dress2 *} {* addressCity *} {* addressPostalCode *} {* addressState *}" \
" {* addressCountry *}</fieldset><br/><div class=\"optHidden\">{* publi" \
"cPrivate *} {* journalistContact *} {* aboutMe *} {* usernameTwPublic " \
"*} {* preferedContactLanguages *} {* arabicUsername *} {* persianUsern" \
"ame *} {* skypeId *} {* usernameTw *} {* journalistContact *} {* publi" \
"cPrivate *} {* profession *}</div><fieldset class=\"newsletters\"><leg" \
"end>Souscrire aux newsletters</legend><div class=\"optHidden optFr\">{" \
"* newsMenu *} {* optinalert *} {* optinBestofWeek *} {* optinBestofWEn" \
"d *} {* optinBestofObs *}</div><div class=\"optHidden optEn\">{* newsM" \
"enuEn *} {* optinalertEn *} {* optinBestofWeekEn *} {* optinBestofWEnd" \
"En *} {* optinBestofObsEn *}</div><div class=\"optHidden optAr\">{* ne" \
"wsMenuAr *} {* optinalertAr *} {* optinBestofWeekAr *} {* optinBestofW" \
"EndAr *} {* optinBestofObsAr *}</div><div class=\"optHidden optEs\">{*" \
" newsMenuEs *} {* optinalertEs *} {* optinbestofweekEs *} {* optinbest" \
"ofwendEs *}</div><div class=\"optHidden optCommonMCD\">{* optinQuotidi" \
"enne *} {* optinBreaking *}</div><div class=\"optHidden optCommonF24\"" \
">{* optinAutopromo *} {* optinPartenaires *}</div><div class=\"optHidd" \
"en optCommonRFI\">{* optinActuMonde *} {* optinActuAfrique *} {* optin" \
"Alert *} {* optinRfiAfriqueFootFr *} {* optinMfi *} {* optinActuMusiqu" \
"e *} {* optinOffreRfi *} {* optinOffrePartenaire *}</div></fieldset><b" \
"r/><div class=\"capture_form_item\"><input value=\"Save\" type=\"submi" \
"t\" class=\"capture_btn capture_primary\"/> {* savedProfileMessage *}<" \
"/div>{* /editProfileModalForm *}</div></div></div></div></div></div></" \
"div><div style=\"display:none\" id=\"changePassword\"><div class=\"cap" \
"ture_header\"><h2>Modifier le mot de passe</h2></div>{* #changePasswor" \
"dForm *} {* currentPassword *} {* newPassword *} {* newPasswordConfirm" \
" *}<div class=\"capture_footer\"><input value=\"Save\" type=\"submit\"" \
" class=\"capture_btn capture_primary\"/></div>{* /changePasswordForm *" \
"}</div><div style=\"display:none\" id=\"confirmAccountDeactivation\"><" \
"div class=\"capture_header\"><h2>D&#xE9;sactivez votre compte</h2></di" \
"v><div class=\"content_wrapper\"><p>Etes-vous s&#xFB;re de vouloir d&#" \
"xE9;sactiver votre compte ? Vous n'aurez plus acc&#xE8;s &#xE0; votre " \
"profil</p>{* deactivateAccountForm *}<div class=\"capture_footer\"><in" \
"put value=\"Yes\" type=\"submit\" class=\"capture_btn capture_primary\"" \
"/><a href=\"#\" id=\"capture_confirmAccountDeactivation_noButton\" onc" \
"lick=\"janrain.capture.ui.modal.close()\" class=\"capture_btn capture_" \
"primary\">Non</a></div></div>{* /deactivateAccountForm *}</div>\n" \
"                </div>\n" \
"                    </div>\n" \
"        <script type=\"text/javascript\" src=\"//nexus.ensighten.com/f" \
"rancemm/f24/Bootstrap.js\"/><script type=\"text/javascript\"><![CDATA[" \
"\n" \
"//<![CDATA[\n" \
"(function() {\n" \
"var _analytics_scr = document.createElement('script');\n" \
"_analytics_scr.type = 'text/javascript'; _analytics_scr.async = true; " \
"_analytics_scr.src = '/_Incapsula_Resource?SWJIYLWA=719d34d31c8e3a6e6f" \
"ffd425f7e032f3&ns=2&cb=506409422';\n" \
"var _analytics_elem = document.getElementsByTagName('script')[0]; _ana" \
"lytics_elem.parentNode.insertBefore(_analytics_scr, _analytics_elem);\n" \
"})();\n" \
"// ]]></script></body></html>\n" \
"\t\t");
#line 126 "GHtmlDocumentTest.vala"
	src = _tmp0_;
#line 1511 "GHtmlDocumentTest.vala"
	_tmp1_ = src;
#line 1511 "GHtmlDocumentTest.vala"
	_tmp2_ = gxml_ghtml_document_new_from_string (_tmp1_, 0);
#line 1511 "GHtmlDocumentTest.vala"
	_g_object_unref0 (doc);
#line 1511 "GHtmlDocumentTest.vala"
	doc = (GXmlDomDocument*) _tmp2_;
#line 1512 "GHtmlDocumentTest.vala"
	_tmp3_ = doc;
#line 1512 "GHtmlDocumentTest.vala"
	_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GDOCUMENT) ? ((GXmlGDocument*) _tmp3_) : NULL));
#line 1512 "GHtmlDocumentTest.vala"
	_tmp5_ = _tmp4_;
#line 1512 "GHtmlDocumentTest.vala"
	g_message ("GHtmlDocumentTest.vala:1512: %s", _tmp5_);
#line 1512 "GHtmlDocumentTest.vala"
	_g_free0 (_tmp5_);
#line 1513 "GHtmlDocumentTest.vala"
	_tmp6_ = doc;
#line 1513 "GHtmlDocumentTest.vala"
	_tmp7_ = gxml_dom_document_get_document_element (_tmp6_);
#line 1513 "GHtmlDocumentTest.vala"
	_tmp8_ = _tmp7_;
#line 1513 "GHtmlDocumentTest.vala"
	_tmp9_ = _tmp8_;
#line 1513 "GHtmlDocumentTest.vala"
	_vala_assert (_tmp9_ != NULL, "doc.document_element != null");
#line 1513 "GHtmlDocumentTest.vala"
	_g_object_unref0 (_tmp9_);
#line 1514 "GHtmlDocumentTest.vala"
	_tmp10_ = doc;
#line 1514 "GHtmlDocumentTest.vala"
	_tmp11_ = gxml_dom_document_get_document_element (_tmp10_);
#line 1514 "GHtmlDocumentTest.vala"
	_tmp12_ = _tmp11_;
#line 1514 "GHtmlDocumentTest.vala"
	_tmp13_ = _tmp12_;
#line 1514 "GHtmlDocumentTest.vala"
	_tmp14_ = gxml_dom_parent_node_get_elements_by_property_value ((GXmlDomParentNode*) _tmp13_, "property", "article:published_time");
#line 1514 "GHtmlDocumentTest.vala"
	_tmp15_ = _tmp14_;
#line 1514 "GHtmlDocumentTest.vala"
	_g_object_unref0 (_tmp13_);
#line 1514 "GHtmlDocumentTest.vala"
	c = _tmp15_;
#line 1102 "GHtmlDocumentTest.c"
	{
		GXmlDomElementList* _n_list = NULL;
		GXmlDomElementList* _tmp16_;
		GXmlDomElementList* _tmp17_;
		gint _n_size = 0;
		GXmlDomElementList* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		gint _n_index = 0;
#line 1515 "GHtmlDocumentTest.vala"
		_tmp16_ = c;
#line 1515 "GHtmlDocumentTest.vala"
		_tmp17_ = _g_object_ref0 (_tmp16_);
#line 1515 "GHtmlDocumentTest.vala"
		_n_list = _tmp17_;
#line 1515 "GHtmlDocumentTest.vala"
		_tmp18_ = _n_list;
#line 1515 "GHtmlDocumentTest.vala"
		_tmp19_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp18_);
#line 1515 "GHtmlDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 1515 "GHtmlDocumentTest.vala"
		_n_size = _tmp20_;
#line 1515 "GHtmlDocumentTest.vala"
		_n_index = -1;
#line 1515 "GHtmlDocumentTest.vala"
		while (TRUE) {
#line 1130 "GHtmlDocumentTest.c"
			GXmlDomNode* n = NULL;
			GXmlDomElementList* _tmp21_;
			gpointer _tmp22_;
			GXmlDomNode* _tmp23_;
			gchar* _tmp24_;
			gchar* _tmp25_;
			gchar* _tmp26_;
#line 1515 "GHtmlDocumentTest.vala"
			_n_index = _n_index + 1;
#line 1515 "GHtmlDocumentTest.vala"
			if (!(_n_index < _n_size)) {
#line 1515 "GHtmlDocumentTest.vala"
				break;
#line 1144 "GHtmlDocumentTest.c"
			}
#line 1515 "GHtmlDocumentTest.vala"
			_tmp21_ = _n_list;
#line 1515 "GHtmlDocumentTest.vala"
			_tmp22_ = gee_abstract_list_get ((GeeAbstractList*) _tmp21_, _n_index);
#line 1515 "GHtmlDocumentTest.vala"
			n = (GXmlDomNode*) ((GXmlDomElement*) _tmp22_);
#line 1516 "GHtmlDocumentTest.vala"
			_tmp23_ = n;
#line 1516 "GHtmlDocumentTest.vala"
			_tmp24_ = gxml_dom_node_get_node_name (_tmp23_);
#line 1516 "GHtmlDocumentTest.vala"
			_tmp25_ = _tmp24_;
#line 1516 "GHtmlDocumentTest.vala"
			_tmp26_ = _tmp25_;
#line 1516 "GHtmlDocumentTest.vala"
			g_message ("GHtmlDocumentTest.vala:1516: %s", _tmp26_);
#line 1516 "GHtmlDocumentTest.vala"
			_g_free0 (_tmp26_);
#line 1515 "GHtmlDocumentTest.vala"
			_g_object_unref0 (n);
#line 1166 "GHtmlDocumentTest.c"
		}
#line 1515 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_n_list);
#line 1170 "GHtmlDocumentTest.c"
	}
#line 1518 "GHtmlDocumentTest.vala"
	_tmp27_ = doc;
#line 1518 "GHtmlDocumentTest.vala"
	_tmp28_ = gxml_dom_parent_node_get_elements_by_property_value ((GXmlDomParentNode*) _tmp27_, "property", "article:published_time");
#line 1518 "GHtmlDocumentTest.vala"
	collection = _tmp28_;
#line 1519 "GHtmlDocumentTest.vala"
	_tmp29_ = collection;
#line 1519 "GHtmlDocumentTest.vala"
	_tmp30_ = gxml_dom_html_collection_get_length ((GXmlDomHTMLCollection*) _tmp29_);
#line 1519 "GHtmlDocumentTest.vala"
	_tmp31_ = _tmp30_;
#line 1519 "GHtmlDocumentTest.vala"
	_tmp32_ = g_strdup_printf ("%i", _tmp31_);
#line 1519 "GHtmlDocumentTest.vala"
	_tmp33_ = _tmp32_;
#line 1519 "GHtmlDocumentTest.vala"
	g_message ("GHtmlDocumentTest.vala:1519: %s", _tmp33_);
#line 1519 "GHtmlDocumentTest.vala"
	_g_free0 (_tmp33_);
#line 1520 "GHtmlDocumentTest.vala"
	_tmp34_ = collection;
#line 1520 "GHtmlDocumentTest.vala"
	_tmp35_ = gxml_dom_html_collection_get_length ((GXmlDomHTMLCollection*) _tmp34_);
#line 1520 "GHtmlDocumentTest.vala"
	_tmp36_ = _tmp35_;
#line 1520 "GHtmlDocumentTest.vala"
	_vala_assert (_tmp36_ == 1, "collection.length == 1");
#line 1200 "GHtmlDocumentTest.c"
	{
		GXmlDomElementList* _n_list = NULL;
		GXmlDomElementList* _tmp37_;
		GXmlDomElementList* _tmp38_;
		gint _n_size = 0;
		GXmlDomElementList* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		gint _n_index = 0;
#line 1521 "GHtmlDocumentTest.vala"
		_tmp37_ = c;
#line 1521 "GHtmlDocumentTest.vala"
		_tmp38_ = _g_object_ref0 (_tmp37_);
#line 1521 "GHtmlDocumentTest.vala"
		_n_list = _tmp38_;
#line 1521 "GHtmlDocumentTest.vala"
		_tmp39_ = _n_list;
#line 1521 "GHtmlDocumentTest.vala"
		_tmp40_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp39_);
#line 1521 "GHtmlDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 1521 "GHtmlDocumentTest.vala"
		_n_size = _tmp41_;
#line 1521 "GHtmlDocumentTest.vala"
		_n_index = -1;
#line 1521 "GHtmlDocumentTest.vala"
		while (TRUE) {
#line 1228 "GHtmlDocumentTest.c"
			GXmlDomNode* n = NULL;
			GXmlDomElementList* _tmp42_;
			gpointer _tmp43_;
			GXmlDomNode* _tmp44_;
			gchar* _tmp45_;
			gchar* _tmp46_;
			gchar* _tmp47_;
#line 1521 "GHtmlDocumentTest.vala"
			_n_index = _n_index + 1;
#line 1521 "GHtmlDocumentTest.vala"
			if (!(_n_index < _n_size)) {
#line 1521 "GHtmlDocumentTest.vala"
				break;
#line 1242 "GHtmlDocumentTest.c"
			}
#line 1521 "GHtmlDocumentTest.vala"
			_tmp42_ = _n_list;
#line 1521 "GHtmlDocumentTest.vala"
			_tmp43_ = gee_abstract_list_get ((GeeAbstractList*) _tmp42_, _n_index);
#line 1521 "GHtmlDocumentTest.vala"
			n = (GXmlDomNode*) ((GXmlDomElement*) _tmp43_);
#line 1522 "GHtmlDocumentTest.vala"
			_tmp44_ = n;
#line 1522 "GHtmlDocumentTest.vala"
			_tmp45_ = gxml_dom_node_get_node_name (_tmp44_);
#line 1522 "GHtmlDocumentTest.vala"
			_tmp46_ = _tmp45_;
#line 1522 "GHtmlDocumentTest.vala"
			_tmp47_ = _tmp46_;
#line 1522 "GHtmlDocumentTest.vala"
			g_message ("GHtmlDocumentTest.vala:1522: %s", _tmp47_);
#line 1522 "GHtmlDocumentTest.vala"
			_g_free0 (_tmp47_);
#line 1521 "GHtmlDocumentTest.vala"
			_g_object_unref0 (n);
#line 1264 "GHtmlDocumentTest.c"
		}
#line 1521 "GHtmlDocumentTest.vala"
		_g_object_unref0 (_n_list);
#line 1268 "GHtmlDocumentTest.c"
	}
#line 125 "GHtmlDocumentTest.vala"
	_g_object_unref0 (collection);
#line 125 "GHtmlDocumentTest.vala"
	_g_object_unref0 (c);
#line 125 "GHtmlDocumentTest.vala"
	_g_object_unref0 (doc);
#line 125 "GHtmlDocumentTest.vala"
	_g_free0 (src);
#line 1278 "GHtmlDocumentTest.c"
}

static void
___lambda45__gtest_func (void)
{
#line 125 "GHtmlDocumentTest.vala"
	__lambda45_ ();
#line 1286 "GHtmlDocumentTest.c"
}

void
ghtml_document_test_add_tests (void)
{
#line 29 "GHtmlDocumentTest.vala"
	g_test_add_func ("/gxml/GHtmlDocument/api/element_id", ___lambda42__gtest_func);
#line 46 "GHtmlDocumentTest.vala"
	g_test_add_func ("/gxml/GHtmlDocument/api/element_class", ___lambda43__gtest_func);
#line 73 "GHtmlDocumentTest.vala"
	g_test_add_func ("/gxml/GHtmlDocument/fom_string_doc", ___lambda44__gtest_func);
#line 125 "GHtmlDocumentTest.vala"
	g_test_add_func ("/gxml/GHtmlDocument/element-by-property", ___lambda45__gtest_func);
#line 1300 "GHtmlDocumentTest.c"
}

GHtmlDocumentTest*
ghtml_document_test_construct (GType object_type)
{
	GHtmlDocumentTest* self = NULL;
#line 27 "GHtmlDocumentTest.vala"
	self = (GHtmlDocumentTest*) gxml_test_construct (object_type);
#line 27 "GHtmlDocumentTest.vala"
	return self;
#line 1311 "GHtmlDocumentTest.c"
}

GHtmlDocumentTest*
ghtml_document_test_new (void)
{
#line 27 "GHtmlDocumentTest.vala"
	return ghtml_document_test_construct (TYPE_GHTML_DOCUMENT_TEST);
#line 1319 "GHtmlDocumentTest.c"
}

static void
ghtml_document_test_class_init (GHtmlDocumentTestClass * klass,
                                gpointer klass_data)
{
#line 27 "GHtmlDocumentTest.vala"
	ghtml_document_test_parent_class = g_type_class_peek_parent (klass);
#line 1328 "GHtmlDocumentTest.c"
}

static void
ghtml_document_test_instance_init (GHtmlDocumentTest * self,
                                   gpointer klass)
{
}

GType
ghtml_document_test_get_type (void)
{
	static volatile gsize ghtml_document_test_type_id__volatile = 0;
	if (g_once_init_enter (&ghtml_document_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GHtmlDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) ghtml_document_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GHtmlDocumentTest), 0, (GInstanceInitFunc) ghtml_document_test_instance_init, NULL };
		GType ghtml_document_test_type_id;
		ghtml_document_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GHtmlDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&ghtml_document_test_type_id__volatile, ghtml_document_test_type_id);
	}
	return ghtml_document_test_type_id__volatile;
}

